@@ -56,7 +56,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: alert.c,v 1.52 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: alert.c,v 1.53 2006/04/27 20:16:03 martinp Exp $
  *  @file
  */
 
@@ -86,7 +86,7 @@ int handle_alert(Event_T E) {
 
   s= Event_get_source(E);
   if(!s) {
-    log("Aborting alert\n");
+    LogError("Aborting alert\n");
     return rv;
   }
 
