@@ -46,7 +46,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: collector.c,v 1.11 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: collector.c,v 1.12 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -88,17 +88,17 @@ int handle_collector(Event_T E) {
     socket_create_t(C->url->hostname, C->url->port, SOCKET_TCP, C->ssl, C->timeout)
   ))
   {
-    log("Collector: cannot open a connection to %s -- %s\n",
+    LogError("Collector: cannot open a connection to %s -- %s\n",
       C->url->url, STRERROR);
 
     if((C= C->next))
     {
-      log("Collector: trying next server %s\n", C->url->url);
+      LogInfo("Collector: trying next server %s\n", C->url->url);
       continue;
     }
     else
     {
-      log("Collector: no server available\n");
+      LogError("Collector: no server available\n");
       rv = HANDLER_COLLECTOR;
       goto exit2;
     }
@@ -108,13 +108,13 @@ int handle_collector(Event_T E) {
 
   if(!data_send(C, D))
   {
-    log("Collector: communication failure\n");
+    LogError("Collector: communication failure\n");
     rv = HANDLER_COLLECTOR;
     goto exit1;
   }
   if(!data_check(C))
   {
-    log("Collector: communication failure\n");
+    LogError("Collector: communication failure\n");
     rv = HANDLER_COLLECTOR;
     goto exit1;
   }
@@ -168,7 +168,8 @@ static int data_send(Collector_T C, char *D) {
   FREE(auth);
   if(rv <0)
   {
-    log("Collector: error sending data to %s -- %s\n", C->url->url, STRERROR);
+    LogError("Collector: error sending data to %s -- %s\n",
+      C->url->url, STRERROR);
     return FALSE;
   }
   return TRUE;
@@ -187,14 +188,15 @@ static int data_check(Collector_T C) {
   char buf[STRLEN];
 
   if(!socket_readln(C->socket, buf, sizeof(buf))) {
-    log("Collector: error receiving data from %s -- %s\n", 
+    LogError("Collector: error receiving data from %s -- %s\n", 
 	C->url->url, STRERROR);
     return FALSE;
   }
   Util_chomp(buf);
   n = sscanf(buf, "%*s %d", &status);
   if(n != 1 || (status >= 400)) {
-    log("Collector: message sending failed to %s -- %s\n", C->url->url, buf);
+    LogError("Collector: message sending failed to %s -- %s\n",
+      C->url->url, buf);
     return FALSE;
   }
   return TRUE;
