@@ -60,7 +60,7 @@
  *  @author Rory Toma, <rory@digeo.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: control.c,v 1.100 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: control.c,v 1.103 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -95,7 +95,7 @@ void control_service_daemon(const char *S, const char *action) {
   ASSERT(action);
   
   if(Util_getAction(action) == ACTION_IGNORE) {
-    log("%s: Cannot %s service '%s' -- invalid action %s\n",
+    LogError("%s: Cannot %s service '%s' -- invalid action %s\n",
         prog, action, S, action);
     goto error;
   }
@@ -105,7 +105,7 @@ void control_service_daemon(const char *S, const char *action) {
   
   if(!s) {
     
-    log("%s: Cannot connect to the monit daemon."
+    LogError("%s: Cannot connect to the monit daemon."
         " Did you start it with http support?\n", prog);
     goto error;
     
@@ -113,7 +113,7 @@ void control_service_daemon(const char *S, const char *action) {
     
     if(socket_print(s, "GET /%s?action=%s HTTP/1.0\r\n%s\r\n", 
                     S, action, auth?auth:"") < 0)
-      log("%s: Cannot send the command '%s' to the monit daemon -- %s", 
+      LogError("%s: Cannot send the command '%s' to the monit daemon -- %s", 
           prog, action?action:"null", STRERROR);
     socket_free(&s);
     
@@ -139,7 +139,7 @@ void control_service(const char *S, const char *action) {
   ASSERT(action);
 
   if(!(s= Util_getService(S))) {
-    log("%s: Cannot %s service '%s' -- not found in %s\n",
+    LogError("%s: Cannot %s service '%s' -- not found in %s\n",
         prog, action, S, Run.controlfile);
     return;
   }
@@ -184,7 +184,7 @@ void control_service(const char *S, const char *action) {
         Util_monitorSet(s);
         return;
       }
-      log("'%s' trying to restart\n", s->name);
+      LogInfo("'%s' trying to restart\n", s->name);
       do_depend(s, ACTION_STOP);
       if(do_stop(s)) {
         /* Only start if stop succeeded */
@@ -212,7 +212,7 @@ void control_service(const char *S, const char *action) {
       break;
 
     default:
-      log("%s: Cannot %s service '%s' -- invalid action %s\n",
+      LogError("%s: Cannot %s service '%s' -- invalid action %s\n",
           prog, action, S, action);
       break;
   }
@@ -269,7 +269,7 @@ static void do_start(Service_T s) {
     int status;
     pthread_t thread;
 
-    log("'%s' start: %s\n", s->name, s->start->arg[0]);
+    LogInfo("'%s' start: %s\n", s->name, s->start->arg[0]);
     spawn(s, s->start, "Started");
     if(s->type==TYPE_PROCESS) {
       /* We only wait for a process type, other service types does not
@@ -282,7 +282,7 @@ static void do_start(Service_T s) {
         LOCK(Run.mutex)
           Run.wait_start--;
         END_LOCK;
-	log("Warning: Failed to create the start controller thread. "
+	LogError("Warning: Failed to create the start controller thread. "
 	    "Thread error -- %s.\n", strerror(status));
       }
     }
@@ -313,14 +313,14 @@ static int do_stop(Service_T s) {
   } 
 
   if(s->stop && (s->type!=TYPE_PROCESS || Util_isProcessRunning(s))) {
-    log("'%s' stop: %s\n", s->name, s->stop->arg[0]);
+    LogInfo("'%s' stop: %s\n", s->name, s->stop->arg[0]);
     spawn(s, s->stop, "Stopped");
 
     if(s->type==TYPE_PROCESS) {
       /* Only wait for process service types */
-      return wait_stop(s);
+      if(!wait_stop(s))
+        return FALSE;
     }
-
   }
 
   Util_resetInfo(s);
