@@ -65,7 +65,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: daemonize.c,v 1.20 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: daemonize.c,v 1.21 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -92,7 +92,7 @@ void  daemonize() {
    */
   if((pid= fork ()) < 0) {
     
-    log("Cannot fork of a new process\n");  
+    LogError("Cannot fork of a new process\n");  
     exit (1);
     
   }  
@@ -106,7 +106,7 @@ void  daemonize() {
 
   if((pid= fork ()) < 0) {
     
-    log("Cannot fork of a new process\n");  
+    LogError("Cannot fork of a new process\n");  
     exit (1);
     
   }  
@@ -123,7 +123,7 @@ void  daemonize() {
    */
   if(chdir("/") < 0) {
     
-    log("Cannot chdir to / -- %s\n", STRERROR);
+    LogError("Cannot chdir to / -- %s\n", STRERROR);
     exit(1);
     
   }
@@ -150,14 +150,15 @@ int kill_daemon(int sig) {
     
     if ( kill(pid, sig) < 0 ) {
       
-      log("%s: Cannot send signal to daemon process -- %s\n",prog, STRERROR);
+      LogError("%s: Cannot send signal to daemon process -- %s\n",
+        prog, STRERROR);
       return FALSE;
       
     }
     
   } else {
     
-    log("%s: No daemon process found\n", prog);
+    LogInfo("%s: No daemon process found\n", prog);
     return TRUE;
     
   }
