@@ -23,7 +23,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: device_common.c,v 1.5 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: device_common.c,v 1.6 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -87,7 +87,7 @@ char *device_path(Info_T inf, char *object) {
   ASSERT(object);
 
   if(stat(object, &buf) != 0) {
-    log("%s: Cannot stat '%s' -- %s\n", prog, object, STRERROR);
+    LogError("%s: Cannot stat '%s' -- %s\n", prog, object, STRERROR);
     return NULL;
   }
 
@@ -101,7 +101,8 @@ char *device_path(Info_T inf, char *object) {
 
   }
 
-  log("%s: Not file, directory or block special device: '%s'", prog, object);
+  LogError("%s: Not file, directory or block special device: '%s'",
+    prog, object);
 
   return NULL;
 
