@@ -23,7 +23,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_LINUX.c,v 1.12 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_LINUX.c,v 1.13 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -77,7 +77,7 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
 
 
   if((mntfd= setmntent("/etc/mtab", "r")) == NULL) {
-    log("%s: Cannot open /etc/mtab file", prog);
+    LogError("%s: Cannot open /etc/mtab file", prog);
     return NULL;
   }
 
@@ -114,7 +114,7 @@ int device_usage_sysdep(Info_T inf) {
   ASSERT(inf);
 
   if(statfs(inf->mntpath, &usage) != 0) {
-    log("%s: Error getting usage statistics for device '%s' -- %s\n",
+    LogError("%s: Error getting usage statistics for device '%s' -- %s\n",
         prog, inf->mntpath, STRERROR);
     return FALSE;
   }
