@@ -22,7 +22,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_NETBSD.c,v 1.3 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_NETBSD.c,v 1.4 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -69,7 +69,7 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
   ASSERT(blockdev);
 
   if(statfs(blockdev, &usage) != 0) {
-    log("%s: Error getting mountpoint for device '%s' -- %s\n",
+    LogError("%s: Error getting mountpoint for device '%s' -- %s\n",
         prog, blockdev, STRERROR);
     return NULL;
   }
@@ -93,7 +93,7 @@ int device_usage_sysdep(Info_T inf) {
   ASSERT(inf);
 
   if(statfs(inf->mntpath, &usage) != 0) {
-    log("%s: Error getting usage statistics for device '%s' -- %s\n",
+    LogError("%s: Error getting usage statistics for device '%s' -- %s\n",
         prog, inf->mntpath, STRERROR);
     return FALSE;
   }
