@@ -23,7 +23,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_OPENBSD.c,v 1.13 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_OPENBSD.c,v 1.14 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -70,7 +70,7 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
   ASSERT(blockdev);
 
   if(statfs(blockdev, &usage) != 0) {
-    log("%s: Error getting mountpoint for device '%s' -- %s\n",
+    LogError("%s: Error getting mountpoint for device '%s' -- %s\n",
         prog, blockdev, STRERROR);
     return NULL;
   }
@@ -94,7 +94,7 @@ int device_usage_sysdep(Info_T inf) {
   ASSERT(inf);
 
   if(statfs(inf->mntpath, &usage) != 0) {
-    log("%s: Error getting usage statistics for device '%s' -- %s\n",
+    LogError("%s: Error getting usage statistics for device '%s' -- %s\n",
         prog, inf->mntpath, STRERROR);
     return FALSE;
   }
