@@ -54,7 +54,7 @@
  *
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  * @author Martin Pala <martinp@tildeslash.com>
- * @version \$Id: event.c,v 1.57 2006/01/01 22:44:01 martinp Exp $
+ * @version \$Id: event.c,v 1.61 2006/04/27 20:16:03 martinp Exp $
  * @file
  */
 
@@ -257,7 +257,7 @@ Service_T Event_get_source(Event_T E) {
 
   if(!(s = Util_getService(E->source)))
   {
-    log("Service %s not found in monit configuration\n", E->source);
+    LogError("Service %s not found in monit configuration\n", E->source);
   }
 
   return s;
@@ -512,8 +512,10 @@ void Event_queue_process() {
 
   if(! (dir = opendir(Run.eventlist_dir)) )
   {
-    log("%s: cannot open the directory %s -- %s\n",
-      prog, Run.eventlist_dir, STRERROR);
+    if(errno != ENOENT) {
+      LogError("%s: cannot open the directory %s -- %s\n",
+        prog, Run.eventlist_dir, STRERROR);
+    }
     return;
   }
 
@@ -560,7 +562,7 @@ void Event_queue_process() {
 
       if(! (file = fopen(file_name, "r")) )
       {
-        log("%s: Processing failed - cannot open the event file %s -- %s\n",
+        LogError("%s: Processing failed - cannot open the event file %s -- %s\n",
           prog, file_name, STRERROR);
         goto error;
       }
@@ -570,7 +572,7 @@ void Event_queue_process() {
         goto error;
       if(*version != EVENT_VERSION)
       {
-        log("Aborting event %s - incompatible data format version %d\n",
+        LogError("Aborting event %s - incompatible data format version %d\n",
           file_name, *version);
         unlink(file_name);
         goto error;
@@ -624,7 +626,7 @@ void Event_queue_process() {
           }
           else
           {
-            log("Alert handler failed, retry scheduled for next cycle\n");
+            LogError("Alert handler failed, retry scheduled for next cycle\n");
             Run.handler_flag |= HANDLER_ALERT;
           }
         }
@@ -646,7 +648,7 @@ void Event_queue_process() {
           }
           else
           {
-            log("Collector handler failed, retry scheduled for next cycle\n");
+            LogError("Collector handler failed, retry scheduled for next cycle\n");
             Run.handler_flag |= HANDLER_COLLECTOR;
           }
         }
@@ -710,7 +712,11 @@ static void handle_event(Event_T E) {
      * logged. */
     if(E->state != STATE_INIT || E->state_map & 0x1)
     {
-      log("%s\n", E->message);
+      if(E->id == EVENT_INSTANCE || E->state == STATE_PASSED) {
+        LogInfo("%s\n", E->message);
+      } else {
+        LogError("%s\n", E->message);
+      }
     }
     if(E->state == STATE_INIT)
     {
@@ -721,7 +727,7 @@ static void handle_event(Event_T E) {
   S = Event_get_source(E);
   if(!S)
   {
-    log("Event handling aborted\n");
+    LogError("Event handling aborted\n");
     return;
   }
 
@@ -770,14 +776,14 @@ static int handle_action(Event_T E, Action_T A) {
     }
     else
     {
-      log("Aborting event\n");
+      LogError("Aborting event\n");
     }
   }
 
   s = Event_get_source(E);
   if(!s)
   {
-    log("Event action handling aborted\n");
+    LogError("Event action handling aborted\n");
     return FALSE;
   }
 
@@ -821,7 +827,7 @@ static int handle_action(Event_T E, Action_T A) {
       return FALSE;
 
   default:
-      log("'%s' error -- unknown failure action: [%d]\n", s->name,
+      LogError("'%s' error -- unknown failure action: [%d]\n", s->name,
         A->id);
       break;
 
@@ -842,22 +848,23 @@ static void Event_queue_add(Event_T E) {
   int          version = EVENT_VERSION;
   short        action = Event_get_action(E);
   int          rv = FALSE;
+  mode_t       mask;
   sigset_t     ns;
   sigset_t     os;
 
   ASSERT(E);
   ASSERT(E->flag != HANDLER_PASSED);
 
-  if(!File_checkQueueDirectory(Run.eventlist_dir, 700))
+  if(!File_checkQueueDirectory(Run.eventlist_dir, 0700))
   {
-    log("%s: Aborting event - cannot access the directory %s\n",
+    LogError("%s: Aborting event - cannot access the directory %s\n",
       prog, Run.eventlist_dir);
     return;
   }
     
   if(!File_checkQueueLimit(Run.eventlist_dir, Run.eventlist_slots))
   {
-    log("%s: Aborting event - queue over quota\n", prog);
+    LogError("%s: Aborting event - queue over quota\n", prog);
     return;
   }
     
@@ -871,9 +878,12 @@ static void Event_queue_add(Event_T E) {
   DEBUG("%s: Adding event to the queue file %s for later delivery\n",
     prog, file_name);
 
-  if(! (file = fopen(file_name, "w")) )
+  mask = umask(QUEUEMASK);
+  file = fopen(file_name, "w");
+  umask(mask);
+  if(! file)
   {
-    log("%s: Aborting event - cannot open the event file %s -- %s\n",
+    LogError("%s: Aborting event - cannot open the event file %s -- %s\n",
       prog, file_name, STRERROR);
     return;
   }
@@ -905,7 +915,7 @@ static void Event_queue_add(Event_T E) {
   error:
   if(!rv)
   {
-    log("%s: Aborting event - unable to save event information to %s\n",
+    LogError("%s: Aborting event - unable to save event information to %s\n",
       prog, file_name);
     unlink(file_name);
   }
