@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2005 by the monit project group.
+ * Copyright (C), 2000-2006 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -22,25 +22,25 @@
 
 #include "monitor.h"
 
-#define EVENT_NULL         0x0
-#define EVENT_CHECKSUM     0x1
-#define EVENT_RESOURCE     0x2
-#define EVENT_TIMEOUT      0x4
-#define EVENT_TIMESTAMP    0x8
-#define EVENT_SIZE         0x10
-#define EVENT_CONNECTION   0x20
-#define EVENT_PERMISSION   0x40
-#define EVENT_UID          0x80
-#define EVENT_GID          0x100
-#define EVENT_NONEXIST     0x200
-#define EVENT_INVALID      0x400
-#define EVENT_DATA         0x800
-#define EVENT_EXEC         0x1000
-#define EVENT_CHANGED      0x2000
-#define EVENT_ICMP         0x4000
-#define EVENT_MATCH        0x8000
+#define EVENT_NULL            0x0
+#define EVENT_CHECKSUM        0x1
+#define EVENT_RESOURCE        0x2
+#define EVENT_TIMEOUT         0x4
+#define EVENT_TIMESTAMP       0x8
+#define EVENT_SIZE            0x10
+#define EVENT_CONNECTION      0x20
+#define EVENT_PERMISSION      0x40
+#define EVENT_UID             0x80
+#define EVENT_GID             0x100
+#define EVENT_NONEXIST        0x200
+#define EVENT_INVALID         0x400
+#define EVENT_DATA            0x800
+#define EVENT_EXEC            0x1000
+#define EVENT_CHANGED         0x2000
+#define EVENT_ICMP            0x4000
+#define EVENT_MATCH           0x8000
+#define EVENT_INSTANCE        0x10000
 
-#define EVENT_DESCRIPTION(E) Event_get_description(E)
 #define IS_EVENT_SET(value, mask) ((value & mask) != 0)
 
 typedef struct myeventtable {
@@ -64,7 +64,7 @@ extern EventTable_T Event_Table[];
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  * @author Martin Pala, <martinp@tildeslash.com>
- * @version \$Id: event.h,v 1.22 2005/09/05 09:51:37 martinp Exp $
+ * @version \$Id: event.h,v 1.25 2006/01/01 22:44:01 martinp Exp $
  * @file
  */
 
@@ -88,6 +88,30 @@ void Event_post(Service_T service, long id, short state, EventAction_T action,
 Service_T Event_get_source(Event_T E);
 
 
+/**
+ * Get the Service name where the event orginated
+ * @param E An event object
+ * @return The Service name where the event orginated
+ */
+char *Event_get_source_name(Event_T E);
+
+
+/**
+ * Get the group name of the service where the event orginated
+ * @param E An event object
+ * @return The group name of the service where the event orginated
+ */
+char *Event_get_source_group(Event_T E);
+
+
+/**
+ * Get the service type of the service where the event orginated
+ * @param E An event object
+ * @return The service type of the service where the event orginated
+ */
+int Event_get_source_type(Event_T E);
+
+
 /**
  * Get the Event timestamp
  * @param E An event object
@@ -164,4 +188,10 @@ short Event_get_action(Event_T E);
 const char *Event_get_action_description(Event_T E);
 
 
+/**
+ * Reprocess the partialy handled event queue
+ */
+void Event_queue_process();
+
+
 #endif
