@@ -68,7 +68,7 @@
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: file.c,v 1.8 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: file.c,v 1.10 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -134,7 +134,7 @@ time_t File_getTimestamp(char *object, mode_t type) {
        ) {
       return MAX(buf.st_mtime, buf.st_ctime);
     } else {
-      log("%s: Invalid object type - %s\n", prog, object);
+      LogError("%s: Invalid object type - %s\n", prog, object);
     }
   }
 
@@ -173,7 +173,7 @@ char *File_findControlFile() {
     snprintf(rcfile, STRLEN, "%s/%s", Run.Env.cwd, MONITRC);
     return (rcfile);
   }
-  log("%s: Cannot find the control file at "
+  LogError("%s: Cannot find the control file at "
       "~/.%s, /etc/%s, /usr/local/etc/%s or at ./%s \n",
       prog, MONITRC, MONITRC, MONITRC, MONITRC);
   exit(1);
@@ -196,7 +196,7 @@ int File_createPidFile(char *pidfile) {
   umask(MYPIDMASK);
   unlink(pidfile);
   if ((F= fopen(pidfile,"w")) == (FILE *)NULL) {
-    log("%s: Error opening pidfile '%s' for writing -- %s\n",
+    LogError("%s: Error opening pidfile '%s' for writing -- %s\n",
 	prog, pidfile, STRERROR);
     return(FALSE);
   }
@@ -292,22 +292,22 @@ int File_checkStat(char *filename, char *description, int permmask) {
   ASSERT(description);
 
   if(lstat(filename, &buf) < 0) {
-    log("%s: Cannot stat the %s '%s' -- %s\n",
+    LogError("%s: Cannot stat the %s '%s' -- %s\n",
 	prog, description, filename, STRERROR);
     return FALSE;
   }
   if(S_ISLNK(buf.st_mode)) {
-    log("%s: The %s '%s' must not be a symbolic link.\n",
+    LogError("%s: The %s '%s' must not be a symbolic link.\n",
 	prog, description, filename);
     return(FALSE);
   }
   if(!S_ISREG(buf.st_mode)) {
-    log("%s: The %s '%s' is not a regular file.\n", 
+    LogError("%s: The %s '%s' is not a regular file.\n", 
 	prog, description,  filename);
     return FALSE;
   }
   if(buf.st_uid != geteuid())  {
-    log("%s: The %s '%s' must be owned by you.\n", 
+    LogError("%s: The %s '%s' must be owned by you.\n", 
 	prog, description, filename);
     return FALSE;
   }
@@ -321,7 +321,7 @@ int File_checkStat(char *filename, char *description, int permmask) {
            () & ~permmask ->      We check if there are any other
                                   permissions set than in permmask 
     */
-    log("%s: The %s '%s' must have permissions no more "
+    LogError("%s: The %s '%s' must have permissions no more "
 	"than -%c%c%c%c%c%c%c%c%c (0%o); "
 	"right now permissions are -%c%c%c%c%c%c%c%c%c (0%o).\n", 
 	prog, description, filename, 
@@ -366,16 +366,22 @@ int File_checkQueueDirectory(char *path, mode_t mode) {
 
   if(stat(path, &st)) {
     if(errno == ENOENT) {
-      if(mkdir(path, mode)) {
-        log("%s: cannot create the directory %s -- %s\n", prog, path, STRERROR);
+      int rv;
+      mode_t mask = umask(QUEUEMASK);
+      rv = mkdir(path, mode);
+      umask(mask);
+      if(rv) {
+        LogError("%s: cannot create the directory %s -- %s\n",
+          prog, path, STRERROR);
         return FALSE;
       }
     } else {
-      log("%s: cannot read the directory %s -- %s\n", prog, path, STRERROR);
+      LogError("%s: cannot read the directory %s -- %s\n",
+        prog, path, STRERROR);
       return FALSE;
     }
   } else if(! S_ISDIR(st.st_mode)) {
-    log("%s: the %s is not the directory\n", prog, path);
+    LogError("%s: the %s is not the directory\n", prog, path);
     return FALSE;
   }
   return TRUE;
@@ -395,19 +401,19 @@ int File_checkQueueLimit(char *path, int limit) {
   struct dirent *de = NULL;
 
   if(limit <= 0) {
-    log("%s: event queue full\n", prog);
+    LogError("%s: event queue full\n", prog);
     return FALSE;
   }
 
   if(! (dir = opendir(path)) ) {
-    log("%s: cannot open the directory %s -- %s\n", prog, path, STRERROR);
+    LogError("%s: cannot open the directory %s -- %s\n", prog, path, STRERROR);
     return FALSE;
   }
   while( (de = readdir(dir)) ) {
     struct stat st;
 
     if(!stat(de->d_name, &st) && S_ISREG(st.st_mode) && ++used > limit) {
-      log("%s: event queue full\n", prog);
+      LogError("%s: event queue full\n", prog);
       closedir(dir);
       return FALSE;
     }
@@ -440,7 +446,7 @@ int File_writeQueue(FILE *file, void *data, int size) {
   return TRUE;
 
   error:
-  log("%s: unable to write data to the file\n", prog);
+  LogError("%s: unable to write data to the file\n", prog);
   return FALSE;
 }
 
@@ -473,7 +479,7 @@ void *File_readQueue(FILE *file, int *size) {
   return data;
 
   error:
-  log("%s: unable to read data from the file\n", prog);
+  LogError("%s: unable to read data from the file\n", prog);
   return FALSE;
 }
 
