@@ -68,7 +68,7 @@ static pthread_t thread;
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: http.c,v 1.7 2006/01/01 22:44:01 martinp Exp $
+ *  @version \$Id: http.c,v 1.8 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -88,7 +88,7 @@ int can_http() {
     
     if(! has_hosts_allow() && ! Run.credentials) {
       
-      log("%s: monit httpd not started since no connect allowed\n",
+      LogError("%s: monit httpd not started since no connect allowed\n",
 	  prog);
       
       return FALSE;
@@ -115,29 +115,29 @@ void monit_http(int action) {
   switch(action) {
     
   case STOP_HTTP:
-    log("Shutting down %s HTTP server\n", prog);
+    LogInfo("Shutting down %s HTTP server\n", prog);
     stop_httpd();
     if( (status= pthread_join(thread, NULL)) != 0) {
-      log("%s: Failed to stop the http server. Thread error -- %s.\n",
+      LogError("%s: Failed to stop the http server. Thread error -- %s.\n",
           prog, strerror(status));
     } else {
-      log("%s HTTP server stopped\n", prog);
+      LogInfo("%s HTTP server stopped\n", prog);
     }
     break;
 
   case START_HTTP:
-    log("Starting %s HTTP server at [%s:%d]\n",
+    LogInfo("Starting %s HTTP server at [%s:%d]\n",
         prog, Run.bind_addr?Run.bind_addr:"*", Run.httpdport);
     if( (status= pthread_create(&thread, NULL, thread_wrapper, NULL)) != 0) {
-      log("%s: Failed to create the http server. Thread error -- %s.\n",
+      LogError("%s: Failed to create the http server. Thread error -- %s.\n",
           prog, strerror(status));
     } else {
-      log("%s HTTP server started\n", prog);
+      LogInfo("%s HTTP server started\n", prog);
     }
     break;
 
   default:
-    log("%s: Unknown http server action\n", prog);
+    LogError("%s: Unknown http server action\n", prog);
     break;
       
   }
