@@ -107,7 +107,7 @@
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *  @author Martin Pala <martinp@tildeslash.com>
  *
- *  @version \$Id: engine.c,v 1.71 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: engine.c,v 1.72 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file 
  */
@@ -155,10 +155,10 @@ void start_httpd(int port, int backlog, char *bindAddr) {
 
   if((myServerSocket= create_server_socket(port, backlog, bindAddr)) < 0) {
     
-    log("http server: Could not create a server socket at port %d -- %s\n",
+    LogError("http server: Could not create a server socket at port %d -- %s\n",
 	port, STRERROR);
     
-    log("monit HTTP server not available\n");
+    LogError("monit HTTP server not available\n");
     
     if(Run.init) {
       
@@ -178,9 +178,9 @@ void start_httpd(int port, int backlog, char *bindAddr) {
       
       if(mySSLServerConnection == NULL) {
 	
-	log("http server: Could not initialize SSL engine\n");
+	LogError("http server: Could not initialize SSL engine\n");
 	
-	log("monit HTTP server not available\n");
+	LogError("monit HTTP server not available\n");
 	
 	return;
       }
@@ -236,7 +236,7 @@ int add_host_allow(char *name) {
 
   if(! (hp= gethostbyname(name))) {
     
-    log("%s: Error: hostname did not resolve '%s'.\n",
+    LogError("%s: Error: hostname did not resolve '%s'.\n",
           prog, name); 
     return FALSE;
     
@@ -422,7 +422,7 @@ static void check_Impl() {
 
   if((Impl.doGet == 0) || (Impl.doPost == 0)) {
     
-    log("http server: Service Methods not implemented\n");
+    LogError("http server: Service Methods not implemented\n");
     _exit(1);
     
   }
@@ -449,7 +449,7 @@ static int authenticate(const struct in_addr addr) {
 
   }
 
-  log("%s: Denied connection from non-authorized client [%s]\n", prog,
+  LogError("%s: Denied connection from non-authorized client [%s]\n", prog,
       inet_ntoa(addr));
   
   return FALSE;
@@ -649,9 +649,9 @@ static Socket_T socket_producer(int server, int port, void *sslserver) {
     if( (client= accept(server, (struct sockaddr*)&in, &len)) < 0) {
 
       if(stopped) {
-        log("http server: service stopped\n");
+        LogError("http server: service stopped\n");
       }  else {
-        log("http server: cannot accept connection -- %s\n", STRERROR);
+        LogError("http server: cannot accept connection -- %s\n", STRERROR);
       }
 
       return NULL;
