@@ -101,7 +101,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: processor.c,v 1.54 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: processor.c,v 1.55 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -781,13 +781,13 @@ static int basic_authenticate(HttpRequest req) {
   }
   /* Check if user exist */
   if(NULL==Util_getUserCredentials(uname)) {
-    log("Warning: Client '%s' supplied unknown user '%s'"
+    LogError("Warning: Client '%s' supplied unknown user '%s'"
 	" accessing monit httpd\n", socket_get_remote_host(req->S), uname); 
     return FALSE;
   }
   /* Check if user has supplied the right password */
   if(! Util_checkCredentials(uname,  password)) {
-    log("Warning: Client '%s' supplied wrong password for user '%s'"
+    LogError("Warning: Client '%s' supplied wrong password for user '%s'"
 	" accessing monit httpd\n", socket_get_remote_host(req->S), uname); 
     return FALSE;
   }
