@@ -81,7 +81,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: monitor.c,v 1.128 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: monitor.c,v 1.129 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -135,7 +135,7 @@ int do_wakeupcall() {
   if((pid= exist_daemon()) > 0) {
     
     kill(pid, SIGUSR1);
-    log("%s daemon at %d awakened\n", prog, pid);
+    LogInfo("%s daemon at %d awakened\n", prog, pid);
     
     return TRUE;
     
@@ -199,7 +199,8 @@ static void do_init() {
    */
   status= pthread_mutex_init(&Run.mutex, NULL);
   if(status != 0) {
-    log("%s: Cannot initialize mutex -- %s\n", prog, strerror(status));
+    LogError("%s: Cannot initialize mutex -- %s\n",
+      prog, strerror(status));
     exit(1);
   }
 
@@ -235,7 +236,7 @@ static void do_init() {
    */
   if(Run.testing) {
 
-    log("Control file syntax OK\n");
+    LogInfo("Control file syntax OK\n");
     exit(0);
 
   }
@@ -254,7 +255,7 @@ static void do_init() {
    */
   if(! servicelist) {
     
-    log("%s: No services has been specified\n", prog);
+    LogError("%s: No services has been specified\n", prog);
     exit(0);
     
   }
@@ -285,8 +286,9 @@ static void do_reinit() {
 
   Run.doreload= FALSE;
   
-  log("Awakened by the SIGHUP signal\n");
-  log("Reinitializing %s - Control file '%s'\n", prog, Run.controlfile);
+  LogInfo("Awakened by the SIGHUP signal\n");
+  LogInfo("Reinitializing %s - Control file '%s'\n",
+    prog, Run.controlfile);
   
   /* Stop http interface */
   if(Run.dohttpd)
@@ -300,7 +302,7 @@ static void do_reinit() {
   gc();
 
   if(! parse(Run.controlfile)) {
-    log("%s daemon died\n", prog);
+    LogError("%s daemon died\n", prog);
     exit(1);
   }
 
@@ -313,7 +315,7 @@ static void do_reinit() {
 
   /* Did we find any services ?  */
   if(! servicelist) {
-    log("%s: No services has been specified\n", prog);
+    LogError("%s: No services has been specified\n", prog);
     exit(0);
   }
   
@@ -321,7 +323,7 @@ static void do_reinit() {
   File_init();
 
   if(! File_createPidFile(Run.pidfile)) {
-    log("%s daemon died\n", prog);
+    LogError("%s daemon died\n", prog);
     exit(1);
   }
 
@@ -379,12 +381,13 @@ static void do_action(char **args) {
 
       }
     } else {
-      log("%s: please specify the configured service name or 'all' after %s\n",
+      LogError("%s: please specify the configured service "
+        "name or 'all' after %s\n",
         prog, action);
       exit(1);
     }
   } else if(IS(action, "reload")) {
-    log("Reinitializing monit daemon\n", prog);
+    LogInfo("Reinitializing monit daemon\n", prog);
     kill_daemon(SIGHUP);
   } else if(IS(action, "status")) {
     status(LEVEL_NAME_FULL);
@@ -395,7 +398,8 @@ static void do_action(char **args) {
   } else if(IS(action, "validate")) {
     validate();
   } else {
-    log("%s: invalid argument -- %s  (-h will show valid arguments)\n",
+    LogError("%s: invalid argument -- %s  (-h will show "
+        "valid arguments)\n",
         prog, action);
     exit(1);
   }
@@ -419,7 +423,7 @@ static void do_exit() {
     if(Run.dohttpd)
       monit_http(STOP_HTTP);
 
-    log("%s daemon with pid [%d] killed\n", prog, (int)getpid());
+    LogInfo("%s daemon with pid [%d] killed\n", prog, (int)getpid());
 
     /* send the monit stop notification */
     Event_post(Run.system, EVENT_INSTANCE, STATE_FAILED,
@@ -453,16 +457,16 @@ static void do_default() {
     Run.once= FALSE;
 
     if(can_http())
-      log("Starting %s daemon with http interface at [%s:%d]\n",
+      LogInfo("Starting %s daemon with http interface at [%s:%d]\n",
           prog, Run.bind_addr?Run.bind_addr:"*", Run.httpdport);
     else
-      log("Starting %s daemon\n", prog);
+      LogInfo("Starting %s daemon\n", prog);
     
     if(Run.init != TRUE)
       daemonize(); 
     
     if(! File_createPidFile(Run.pidfile)) {
-      log("%s daemon died\n", prog);
+      LogError("%s daemon died\n", prog);
       exit(1);
     }
 
@@ -486,7 +490,7 @@ static void do_default() {
 
       if(Run.dowakeup) {
         Run.dowakeup = FALSE;
-        log("Awakened by User defined signal 1\n");
+        LogInfo("Awakened by User defined signal 1\n");
       }
       
       if(Run.stopped) {
@@ -533,7 +537,7 @@ static void handle_options(int argc, char **argv) {
 	Run.isdaemon= TRUE;
  	sscanf(optarg, "%d", &Run.polltime);
 	if(Run.polltime<1) {
-	  log("%s: option -%c requires a natural number\n", prog, opt);
+	  LogError("%s: option -%c requires a natural number\n", prog, opt);
 	  exit(1);
 	}
 	break;
@@ -598,10 +602,10 @@ static void handle_options(int argc, char **argv) {
 	case 'l':
 	case 'p':
 	case 's':
-	    log("%s: option -- %c requires an argument\n", prog, optopt);
+	    LogError("%s: option -- %c requires an argument\n", prog, optopt);
 	    break;
 	default:
-	    log("%s: invalid option -- %c  (-h will show valid options)\n",
+	    LogError("%s: invalid option -- %c  (-h will show valid options)\n",
 		  prog, optopt);
 	    
 	}
