@@ -55,6 +55,10 @@
 #include <regex.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
+#include <syslog.h>
+#endif
+
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -70,6 +74,8 @@
 #define STRLEN             256
 #define ARGMAX             64
 #define HTTP_CONTENT_MAX   (1024*1000)
+/* Set event queue directory mode: "drwx------" */
+#define QUEUEMASK          0077
 /* Set log file mode: "-rw-rw-r--" */
 #define LOGMASK            0112
 /* Set pid file mode: "-rw-r--r--" */
@@ -181,10 +187,6 @@
 /** ------------------------------------------------- Special purpose macros */
 
 
-/* Mask compiler built-in namespace (C99) and reserved identifiers as
- *  well as external identifiers (in libraries we link with). */
-#define log  log_log
-
 /* Replace the standard signal function with a more reliable using
  * sigaction. Taken from Stevens APUE book. */
 typedef void Sigfunc(int);
@@ -202,7 +204,7 @@ Sigfunc *signal(int signo, Sigfunc * func);
 #undef MIN
 #define MIN(x,y) ((x) < (y) ? (x) : (y))
 #define IS(a,b)  ((a&&b)?!strcasecmp(a, b):0)
-#define DEBUG if(Run.debug) log
+#define DEBUG if(Run.debug) LogDebug
 #define FLAG(x, y) (x & y) == y 
 #define NVLSTR(x) (x?x:"")
 
@@ -225,7 +227,7 @@ Sigfunc *signal(int signo, Sigfunc * func);
 /** ------------------------------------------ Simple Assert Exception macro */
 
 
-#define ASSERT(e) if(!(e)) { log("AssertException: at %s:%d\naborting..\n", \
+#define ASSERT(e) if(!(e)) { LogCritical("AssertException: at %s:%d\naborting..\n", \
     __FILE__, __LINE__); abort(); }
 
 
@@ -793,7 +795,14 @@ void  reset_depend();
 void  spawn(Service_T, Command_T, const char *);
 int   status(char *);
 int   log_init() ;
-void  log_log(const char *, ...) ;
+void  LogEmergency(const char *, ...);
+void  LogAlert(const char *, ...);
+void  LogCritical(const char *, ...);
+void  LogError(const char *, ...);
+void  LogWarning(const char *, ...);
+void  LogNotice(const char *, ...);
+void  LogInfo(const char *, ...);
+void  LogDebug(const char *, ...);
 void  log_close();
 void  validate() ;
 void  daemonize() ;
