@@ -61,7 +61,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: process.c,v 1.30 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: process.c,v 1.31 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -199,7 +199,7 @@ int update_system_load(ProcessTree_T *pt, int treesize) {
     /** Get load average triplet */
     if(-1 == getloadavg_sysdep(systeminfo.loadavg, 3))
     {
-      log("'%s' statistic error -- load average gathering failed\n",
+      LogError("'%s' statistic error -- load average gathering failed\n",
         Run.system->name);
       goto error1;
     }
@@ -216,7 +216,7 @@ int update_system_load(ProcessTree_T *pt, int treesize) {
       }
       else
       {
-        log("'%s' statistic error -- memory usage gathering failed\n",
+        LogError("'%s' statistic error -- memory usage gathering failed\n",
           Run.system->name);
         goto error2;
       }
@@ -238,7 +238,7 @@ int update_system_load(ProcessTree_T *pt, int treesize) {
       }
       else
       {
-        log("'%s' statistic error -- cpu usage gathering failed\n",
+        LogError("'%s' statistic error -- cpu usage gathering failed\n",
           Run.system->name);
         goto error3;
       }
