@@ -65,7 +65,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala <martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_DARWIN.c,v 1.25 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_DARWIN.c,v 1.26 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -144,20 +144,20 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
   struct kinfo_proc *pinfo;
 
   if(getuid()!=0) {
-    log("system statistic error -- permission denied\n");
+    LogError("system statistic error -- permission denied\n");
     return FALSE;
   }
 
   if(!(kvm_handle = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL)))
   {
-    log("system statistic error -- cannot initialize kvm interface\n");
+    LogError("system statistic error -- cannot initialize kvm interface\n");
     return FALSE;
   }
 
   pinfo = kvm_getprocs(kvm_handle, KERN_PROC_ALL, 0, &treesize);
   if(!pinfo || (treesize < 1))
   {
-    log("system statistic error -- cannot get process tree\n");
+    LogError("system statistic error -- cannot get process tree\n");
     kvm_close(kvm_handle);
     return FALSE;
   }
