@@ -86,7 +86,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Arkadiusz Miskiewicz <arekm@pld-linux.org>
  *
- *  @version \$Id: sysdep_LINUX.c,v 1.31 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_LINUX.c,v 1.32 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -176,7 +176,7 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
   /* Find all processes in the /proc directory */
   if(glob("/proc/[0-9]*", GLOB_ONLYDIR, NULL, &globbuf))
   {
-    log("system statistic error -- glob failed\n");
+    LogError("system statistic error -- glob failed\n");
     return FALSE;
   } 
 
@@ -289,40 +289,43 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
   
   if(!read_proc_file(buf, 1024, "meminfo", -1))
   {
-    log("system statistic error -- cannot get real memory free amount\n");
+    LogError("system statistic error -- cannot get real memory free amount\n");
     goto error;
   }
 
   if(!(ptr= strstr(buf, MEMFREE)))
   {
-    log("system statistic error -- cannot get real memory free amount\n");
+    LogError("system statistic error -- cannot get real memory free amount\n");
     goto error;
   }
   if(sscanf(ptr + strlen(MEMFREE), "%ld", &mem_free) != 1)
   {
-    log("system statistic error -- cannot get real memory free amount\n");
+    LogError("system statistic error -- cannot get real memory free amount\n");
     goto error;
   }
 
   if(!(ptr= strstr(buf, MEMBUF)))
   {
-    log("system statistic error -- cannot get real memory beffers amount\n");
+    LogError("system statistic error -- cannot get real memory buffers "
+      "amount\n");
     goto error;
   }
   if(sscanf(ptr + strlen(MEMBUF), "%ld", &buffers) != 1)
   {
-    log("system statistic error -- cannot get real memory buffers amount\n");
+    LogError("system statistic error -- cannot get real memory buffers "
+      "amount\n");
     goto error;
   }
 
   if(!(ptr= strstr(buf, MEMCACHE)))
   {
-    log("system statistic error -- cannot get real memory cache amount\n");
+    LogError("system statistic error -- cannot get real memory cache amount\n");
     goto error;
   }
   if(sscanf(ptr + strlen(MEMCACHE), "%ld", &cached) != 1)
   {
-    log("system statistic error -- cannot get real memory cache free amount\n");
+    LogError("system statistic error -- cannot get real memory cache free "
+      "amount\n");
     goto error;
   }
 
@@ -330,14 +333,14 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
 
   if(si->total_mem_kbyte < 0)
   {
-    log("system statistic error -- memory usage statistic error\n");
+    LogError("system statistic error -- memory usage statistic error\n");
     goto error;
   }
 
   return TRUE;
 
   error:
-  log("system statistic error -- memory usage gathering failed\n");
+  LogError("system statistic error -- memory usage gathering failed\n");
   si->total_mem_kbyte = 0;
   return FALSE;
 }
@@ -357,14 +360,14 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
 
   if(!read_proc_file(buf, 1024, "stat", -1))
   {
-    log("system statistic error -- cannot read /proc/stat\n");
+    LogError("system statistic error -- cannot read /proc/stat\n");
     goto error;
   }
 
   rv = sscanf(buf, "cpu %ld %*d %ld %*d %ld", &cpu_user, &cpu_syst, &cpu_wait);
   if(rv < 2 || rv > 3)
   {
-    log("system statistic error -- cannot read cpu usage\n");
+    LogError("system statistic error -- cannot read cpu usage\n");
     goto error;
   }
   else
