@@ -69,7 +69,7 @@
  *  @author Rory Toma <rory@digeo.com>
  *  @author Martin Pala<martinp@tildeslash.com>
  *
- *  @version \$Id: sysdep_NETBSD.c,v 1.4 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_NETBSD.c,v 1.5 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -148,20 +148,20 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
   struct kinfo_proc *pinfo;
 
   if(getuid()!=0) {
-    log("system statistic error -- permission denied\n");
+    LogError("system statistic error -- permission denied\n");
     return FALSE;
   }
 
   if(!(kvm_handle = kvm_open(NULL, NULL, NULL, O_RDONLY, NULL)))
   {
-    log("system statistic error -- cannot initialize kvm interface\n");
+    LogError("system statistic error -- cannot initialize kvm interface\n");
     return FALSE;
   }
 
   pinfo = kvm_getprocs(kvm_handle, KERN_PROC_ALL, 0, &treesize);
   if(!pinfo || (treesize < 1))
   {
-    log("system statistic error -- cannot get process tree\n");
+    LogError("system statistic error -- cannot get process tree\n");
     kvm_close(kvm_handle);
     return FALSE;
   }
@@ -213,7 +213,8 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
 
   if(sysctl(mib, 2, &vm, &len, NULL, 0) == -1)
   {
-    log("system statistic error -- cannot get real memory usage: %s\n", STRERROR);
+    LogError("system statistic error -- cannot get real memory usage: %s\n",
+      STRERROR);
     return FALSE;
   }
 
@@ -237,7 +238,7 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
   len = sizeof(cp_time);
   if(sysctl(mib, 2, &cp_time, &len, NULL, 0) == -1)
   {
-    log("system statistic error -- cannot get cpu time: %s\n", STRERROR);
+    LogError("system statistic error -- cannot get cpu time: %s\n", STRERROR);
     return FALSE;
   }
 
