@@ -90,7 +90,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: sysdep_SOLARIS.c,v 1.18 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sysdep_SOLARIS.c,v 1.19 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -262,7 +262,7 @@ int used_system_memory_sysdep(SystemInfo_T *si) {
   kstat = kstat_lookup(kctl, "unix", 0, "system_pages");
 
   if (kstat_read(kctl, kstat, 0) == -1) {
-    log("system statistic error -- memory usage gathering failed\n");
+    LogError("system statistic error -- memory usage gathering failed\n");
     kstat_close(kctl);
     return FALSE;
   }
