@@ -61,7 +61,7 @@ static int check_apache_stat(Socket_T s);
  * even with ExtendedStatus Off on Apache config file.
  *
  * @author David Fletcher, <david@megapico.co.uk>
- * @version \$Id: apache_status.c,v 1.6 2006/01/01 22:44:02 martinp Exp $
+ * @version \$Id: apache_status.c,v 1.7 2006/04/27 20:16:03 martinp Exp $
  * @file
  */
 int check_apache_status(Socket_T s) {
@@ -78,7 +78,7 @@ int check_apache_status(Socket_T s) {
 		  "Connection: close\r\n\r\n",
 		  request, Util_getHTTPHostHeader(s, host, STRLEN), 
 		  prog, VERSION) < 0) {
-    log("HTTP: error sending data -- %s\n", STRERROR);
+    LogError("HTTP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
   
@@ -149,7 +149,8 @@ static int check_apache_stat(Socket_T s) {
     if(Util_startsWith(line, "Scoreboard")) {   
       if(1 != sscanf(line, "%*s%*[: ]%s", search_string)) {
        Util_chomp(line);
-       log("APACHE-STATUS error: parsing Apache status response '%s'\n", line);
+       LogError("APACHE-STATUS error: parsing Apache status response '%s'\n",
+         line);
        return FALSE;
       }else{
         scored = 1;
@@ -161,7 +162,7 @@ static int check_apache_stat(Socket_T s) {
   
   /* Check that some scoreboard line was found, if not return an error */
   if(!scored){
-    log("APACHE-STATUS error: no scoreboard line returned by Apache\n");
+    LogError("APACHE-STATUS error: no scoreboard line returned by Apache\n");
     return FALSE;
   }
   
@@ -206,7 +207,7 @@ static int check_apache_stat(Socket_T s) {
   }
 
   if(active_servers <= 0){
-    log("APACHE-STATUS warning: No idle server or threads found\n");
+    LogError("APACHE-STATUS warning: No idle server or threads found\n");
     /* This is not really an error, only a very bussy server */
     return TRUE;
   }
@@ -218,7 +219,7 @@ static int check_apache_stat(Socket_T s) {
   if(loglimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.loglimitOP, 
 			    (100 * no_logging / active_servers), loglimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
           " %i percent of Apache processes are logging\n", loglimit);
       errors++;
     }
@@ -227,7 +228,7 @@ static int check_apache_stat(Socket_T s) {
   if(startlimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.startlimitOP, 
 			    (100 * no_start / active_servers), startlimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
           " %i percent of Apache processes are starting\n", startlimit);
       errors++;
     }
@@ -236,7 +237,7 @@ static int check_apache_stat(Socket_T s) {
   if(requestlimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.requestlimitOP, 
 		    (100 * no_request / active_servers), requestlimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
           " %i percent of Apache processes are reading requests\n", 
 	  requestlimit);
       errors++;
@@ -246,7 +247,7 @@ static int check_apache_stat(Socket_T s) {
   if(replylimit > 0 ){
     if(Util_evalQExpression(myPort->ApacheStatus.replylimitOP, 
 			    (100 * no_reply / active_servers), replylimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
           " %i percent of Apache processes are sending a reply\n", replylimit);
       errors++;
     }
@@ -255,7 +256,7 @@ static int check_apache_stat(Socket_T s) {
   if(keepalivelimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.keepalivelimitOP, 
 		    (100 * no_keepalive / active_servers), keepalivelimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
 	  " %i percent of Apache processes are in keepalive\n", keepalivelimit);
       errors++;
     }
@@ -264,7 +265,7 @@ static int check_apache_stat(Socket_T s) {
   if(dnslimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.dnslimitOP, 
 			    (100 * no_dns / active_servers), dnslimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
 	  " %i percent of Apache processes are waiting for DNS\n", dnslimit);
       errors++;
     }
@@ -273,7 +274,7 @@ static int check_apache_stat(Socket_T s) {
   if(closelimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.closelimitOP, 
 			    (100 * no_close / active_servers), closelimit)){
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
 	  " %i percent of Apache processes are closing connections\n", 
 	  closelimit);
       errors++;
@@ -283,7 +284,7 @@ static int check_apache_stat(Socket_T s) {
   if(gracefullimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.gracefullimitOP, 
 		     (100 * no_graceful / active_servers), gracefullimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
 	  " %i percent of Apache processes are finishing gracefully\n", 
 	  gracefullimit);
       errors++;
@@ -293,7 +294,7 @@ static int check_apache_stat(Socket_T s) {
   if(cleanuplimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.cleanuplimitOP, 
 		    (100 * no_cleanup / active_servers), cleanuplimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
 	  " %i percent of Apache processes are in idle cleanup\n", 
 	  cleanuplimit);
       errors++;
@@ -303,7 +304,7 @@ static int check_apache_stat(Socket_T s) {
   if(waitlimit > 0){
     if(Util_evalQExpression(myPort->ApacheStatus.waitlimitOP, 
 			    (100 * no_wait / active_servers), waitlimit)) {
-      log("APACHE-STATUS error:"
+      LogError("APACHE-STATUS error:"
 	  " %i percent of Apache processes are waiting for a connection\n", 
 	  waitlimit);
       errors++;
