@@ -48,7 +48,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: dns.c,v 1.4 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: dns.c,v 1.5 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -106,21 +106,21 @@ int check_dns(Socket_T s)
       offset_response = 2; /*  Skip Length field in response */
       break;
     default:
-      log("DNS: unsupported socket type -- protocol test skipped\n");
+      LogError("DNS: unsupported socket type -- protocol test skipped\n");
       return TRUE;
   }
 
   if(socket_write(s, (unsigned char *)request + offset_request,
                   sizeof(request) - offset_request) < 0)
   {
-    log("DNS: error sending query -- %s\n", STRERROR);
+    LogError("DNS: error sending query -- %s\n", STRERROR);
     return FALSE;
   }
 
   /* Response should have at least 14 bytes */
   if(socket_read(s, (unsigned char *)buf, 15) <= 14)
   {
-    log("DNS: error receiving response -- %s\n", STRERROR);
+    LogError("DNS: error receiving response -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -129,7 +129,7 @@ int check_dns(Socket_T s)
   /* Compare transaction ID (it should be the same as in our request): */
   if(response[0] != 0x00 && response[1] != 0x01)
   {
-    log("DNS: transaction ID mismatch\n");
+    LogError("DNS: transaction ID mismatch\n");
     return FALSE;
   }
 
@@ -137,27 +137,27 @@ int check_dns(Socket_T s)
 
   if((response[2] & 0x80) != 0x80) /* Response type */
   {
-    log("DNS: message is not response\n");
+    LogError("DNS: message is not response\n");
     return FALSE;
   }
 
   if((response[3] & 0x0F) != 0x00) /* Response code */
   {
-    log("DNS: invalid reply code -- error occured\n");
+    LogError("DNS: invalid reply code -- error occured\n");
     return FALSE;
   }
 
   /* Compare queries count (it should be one as in our request): */
   if(response[4] != 0x00 && response[5] != 0x01)
   {
-    log("DNS: query count mismatch\n");
+    LogError("DNS: query count mismatch\n");
     return FALSE;
   }
 
   /* Compare answer resource records count (it should not be zero): */
   if(response[6] == 0x00 && response[7] == 0x00)
   {
-    log("DNS: no answer records returned\n");
+    LogError("DNS: no answer records returned\n");
     return FALSE;
   }
 
