@@ -63,7 +63,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: dwp.c,v 1.15 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: dwp.c,v 1.16 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -80,12 +80,12 @@ int check_dwp(Socket_T s) {
 
   if(socket_print(s, "HEAD / HTTP/1.1\r\n"
 		  "Connection: close\r\n\r\n") < 0) {
-    log("DWP: error sending data -- %s\n", STRERROR);
+    LogError("DWP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
   
   if(! socket_readln(s, buf, sizeof(buf))) {
-    log("DWP: error receiving data -- %s\n", STRERROR);
+    LogError("DWP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -93,7 +93,7 @@ int check_dwp(Socket_T s) {
 
   n= sscanf(buf, "%s %d", proto, &status);
   if(n!=2 || (status >= 400)) {
-    log("DWP error: %s\n", buf);
+    LogError("DWP error: %s\n", buf);
     return FALSE;
   }
   
