@@ -40,7 +40,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Michael Amster, <mamster@webeasy.com>
  *
- *  @version \$Id: ftp.c,v 1.24 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: ftp.c,v 1.25 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -52,7 +52,7 @@ int check_ftp(Socket_T s) {
   ASSERT(s);
 
   if(!socket_readln(s, buf, STRLEN)) {
-    log("FTP: error receiving data -- %s\n", STRERROR);
+    LogError("FTP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -60,17 +60,17 @@ int check_ftp(Socket_T s) {
   
   sscanf(buf, "%d %*s", &status);
   if(status != 220) {
-    log("FTP error: %s\n", buf);
+    LogError("FTP error: %s\n", buf);
     return FALSE;
   }
 
   if(socket_print(s, "QUIT\r\n") < 0) {
-    log("FTP: error sending data -- %s\n", STRERROR);
+    LogError("FTP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(!socket_readln(s, buf, STRLEN)) {
-    log("FTP: error receiving data -- %s\n", STRERROR);
+    LogError("FTP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -78,7 +78,7 @@ int check_ftp(Socket_T s) {
 
   sscanf(buf, "%d %*s", &status);
   if(status != 221) {
-    log("FTP error: %s\n", buf);
+    LogError("FTP error: %s\n", buf);
     return FALSE;
   }
 
