@@ -42,11 +42,11 @@
 #include "protocol.h"
 
 /**
- *  Generic test service test.
+ *  Generic service test.
  *
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: generic.c,v 1.16 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: generic.c,v 1.19 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -66,11 +66,17 @@ int check_generic(Socket_T s) {
   }
     
   while (g != NULL) {
+    
     if (g->send != NULL) {
+      
+      /* Unescape any \0x00 escaped chars in g's send string 
+      to allow sending a string containing \0 bytes also */
+      char *X= xstrdup(g->send);
+      int l= Util_handle0Escapes(X);
+      
+      if(socket_write(s, X, l) < 0) {
 
-      if(socket_print(s, "%s", g->send) < 0) {
-
-        log("GENERIC: error sending data -- %s\n", STRERROR);
+        LogError("GENERIC: error sending data -- %s\n", STRERROR);
         return FALSE;
 
       } else {
@@ -78,13 +84,15 @@ int check_generic(Socket_T s) {
         DEBUG("GENERIC: successfully sent: '%s'\n", g->send); 
         
       }
-                
+      
+      FREE(X);          
+      
     } else if (g->expect != NULL) {
       int n; 
       /* Need read, not readln here */
       if((n= socket_read(s, buf, STRLEN))<0) {
         
-        log("GENERIC: error receiving data -- %s\n", STRERROR);
+        LogError("GENERIC: error receiving data -- %s\n", STRERROR);
         return FALSE;
         
       }
@@ -98,7 +106,7 @@ int check_generic(Socket_T s) {
                             0);
       if (regex_return != 0) {
 
-        log("GENERIC: receiving unexpected data [%s]\n", buf);
+        LogError("GENERIC: receiving unexpected data [%s]\n", buf);
         return FALSE;
 
       } else {
@@ -112,7 +120,7 @@ int check_generic(Socket_T s) {
 
       if ( strncmp(buf, g->expect, strlen(g->expect)) != 0 ) {
 
-        log("GENERIC: receiving unexpected data [%s]\n", buf);
+        LogError("GENERIC: receiving unexpected data [%s]\n", buf);
         return FALSE;
 
       } else {
@@ -126,7 +134,7 @@ int check_generic(Socket_T s) {
     } else {
 
       /* This should not happen */
-      log("GENERIC: unexpected strageness\n");
+      LogError("GENERIC: unexpected strageness\n");
       return FALSE;
       
     }
@@ -138,4 +146,3 @@ int check_generic(Socket_T s) {
     
 }
 
- 
