@@ -43,7 +43,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: imap.c,v 1.19 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: imap.c,v 1.20 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -57,31 +57,31 @@ int check_imap(Socket_T s) {
   ASSERT(s);
   
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("IMAP: error receiving data -- %s\n", STRERROR);
+    LogError("IMAP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
   Util_chomp(buf);
   
   if(strncasecmp(buf, ok, strlen(ok)) != 0) {
-    log("IMAP error: %s\n", buf);
+    LogError("IMAP error: %s\n", buf);
     return FALSE;
   }
   
   if(socket_print(s, "001 LOGOUT\r\n") < 0) {
-    log("IMAP: error sending data -- %s\n", STRERROR);
+    LogError("IMAP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("IMAP: error receiving data -- %s\n", STRERROR);
+    LogError("IMAP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
   Util_chomp(buf);
   
   if(strncasecmp(buf, bye, strlen(bye)) != 0) {
-    log("IMAP error: %s\n", buf);
+    LogError("IMAP error: %s\n", buf);
     return FALSE;
   }
 
