@@ -49,7 +49,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: ldap2.c,v 1.15 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: ldap2.c,v 1.16 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -123,24 +123,24 @@ int check_ldap2(Socket_T s) {
 
 
   if(socket_write(s, (unsigned char *)request, sizeof(request)) < 0) {
-    log("LDAP: error sending data -- %s\n", STRERROR);
+    LogError("LDAP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(socket_read(s, (unsigned char *)buf, sizeof(response)) <= 0) {
-    log("LDAP: error receiving data -- %s\n", STRERROR);
+    LogError("LDAP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(memcmp((unsigned char *)buf,
 	    (unsigned char *)response,
 	    sizeof(response))) {
-    log("LDAP: anonymous bind failed\n");
+    LogError("LDAP: anonymous bind failed\n");
     return FALSE;
   }
 
   if(socket_write(s, (unsigned char *)unbind, sizeof(unbind)) < 0) {
-    log("LDAP: error sending data -- %s\n", STRERROR);
+    LogError("LDAP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
 
