@@ -39,7 +39,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: nntp.c,v 1.20 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: nntp.c,v 1.21 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -51,7 +51,7 @@ int check_nntp(Socket_T s) {
   ASSERT(s);
 
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("NNTP: error receiving data -- %s\n", STRERROR);
+    LogError("NNTP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -59,17 +59,17 @@ int check_nntp(Socket_T s) {
   
   sscanf(buf, "%d %*s", &status);
   if(status != 200) {
-    log("NNTP error: %s\n", buf);
+    LogError("NNTP error: %s\n", buf);
     return FALSE;
   }
   
   if(socket_print(s, "QUIT\r\n") < 0) {
-    log("NNTP: error sending data -- %s\n", STRERROR);
+    LogError("NNTP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("NNTP: error receiving data -- %s\n", STRERROR);
+    LogError("NNTP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -77,7 +77,7 @@ int check_nntp(Socket_T s) {
 
   sscanf(buf, "%d %*s", &status);
   if(status != 205) {
-    log("NNTP error: %s\n", buf);
+    LogError("NNTP error: %s\n", buf);
     return FALSE;
   }
 
