@@ -37,7 +37,7 @@
  *
  *  @author Michel Marti, <michel.marti@objectxp.com>
  *
- *  @version \$Id: ntp3.c,v 1.7 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: ntp3.c,v 1.10 2006/04/27 20:16:03 martinp Exp $
  *
  */
 
@@ -82,18 +82,19 @@ int check_ntp3(Socket_T s)
 
   /* Send request to NTP server */
   if( (br= socket_write(s, ntpRequest, NTPLEN)) <= 0 ) {
-    log("NTP: error sending NTP request -- %s\n", STRERROR);
+    LogError("NTP: error sending NTP request -- %s\n", STRERROR);
     return FALSE;
   }
 
   /* Receive and validate response */
   if( (br= socket_read(s, ntpResponse, NTPLEN)) <= 0) {
-    log("NTP: did not receive answer from server -- %s\n", STRERROR);
+    LogError("NTP: did not receive answer from server -- %s\n", STRERROR);
     return FALSE;
   }
 
   if( br != NTPLEN ) {
-    log("NTP: Received %d bytes from server, expected %d bytes\n", br, NTPLEN);
+    LogError("NTP: Received %d bytes from server, expected %d bytes\n",
+      br, NTPLEN);
     return FALSE;
   }
 
@@ -103,17 +104,19 @@ int check_ntp3(Socket_T s)
        bits 2-4 ... Version Number
        bits 5-7 ... Mode
    */
-  if( ntpResponse[0] != 
-        (
-          (NTP_LEAP_NOWARN << 6)
-          |
-          (NTP_VERSION << 3)
-          |
-          (NTP_MODE_SERVER)
-        )
-    )
+  if( (ntpResponse[0] & 0x07) != NTP_MODE_SERVER )
   {
-    log("NTP: Server response error\n");
+    LogError("NTP: Server mode error\n");
+    return FALSE;
+  }
+  if( (ntpResponse[0] & 0x38) != NTP_VERSION<<3 )
+  {
+    LogError("NTP: Server protocol version error\n");
+    return FALSE;
+  }
+  if( (ntpResponse[0] & 0xc0) == NTP_LEAP_NOTSYNC<<6 )
+  {
+    LogError("NTP: Server not synchronized\n");
     return FALSE;
   }
 
