@@ -43,7 +43,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: pop.c,v 1.19 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: pop.c,v 1.20 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -55,31 +55,31 @@ int check_pop(Socket_T s) {
   ASSERT(s);
   
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("POP: error receiving data -- %s\n", STRERROR);
+    LogError("POP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
   Util_chomp(buf);
   
   if(strncasecmp(buf, ok, strlen(ok)) != 0) {
-    log("POP error: %s\n", buf);
+    LogError("POP error: %s\n", buf);
     return FALSE;
   }
   
   if(socket_print(s, "QUIT\r\n") < 0) {
-    log("POP: error sending data -- %s\n", STRERROR);
+    LogError("POP: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("POP: error receiving data -- %s\n", STRERROR);
+    LogError("POP: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
   Util_chomp(buf);
   
   if(strncasecmp(buf, ok, strlen(ok)) != 0) {
-    log("POP error: %s\n", buf);
+    LogError("POP error: %s\n", buf);
     return FALSE;
   }
 
