@@ -66,7 +66,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: postfix_policy.c,v 1.3 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: postfix_policy.c,v 1.4 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -85,19 +85,20 @@ int check_postfix_policy(Socket_T s) {
     "client_address=1.2.3.4\n"
     "client_name=mx.foo.tld\n"
     "\n") < 0) {
-    log("POSTFIX-POLICY: error sending data -- %s\n", STRERROR);
+    LogError("POSTFIX-POLICY: error sending data -- %s\n", STRERROR);
     return FALSE;
   }
   
   if(! socket_readln(s, buf, sizeof(buf))) {
-    log("POSTFIX-POLICY: error receiving data -- %s\n", STRERROR);
+    LogError("POSTFIX-POLICY: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
 
   Util_chomp(buf);
 
   if( (strlen(buf) <= 7) || strncasecmp(buf, "action=", 7) ) {
-    log("POSTFIX-POLICY error: %s\n", (buf && *buf)?buf:"no action returned");
+    LogError("POSTFIX-POLICY error: %s\n",
+      (buf && *buf)?buf:"no action returned");
     return FALSE;
   }
   
