@@ -54,6 +54,7 @@ static Protocol_T myssh= NULL;
 static Protocol_T myrdate= NULL;
 static Protocol_T myrsync= NULL;
 static Protocol_T mytns= NULL;
+static Protocol_T mypgsql= NULL;
 
 
 /**
@@ -62,7 +63,7 @@ static Protocol_T mytns= NULL;
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: protocol.c,v 1.26 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: protocol.c,v 1.27 2006/01/22 19:47:36 hauk Exp $
  *
  *  @file
  */
@@ -93,6 +94,7 @@ void gc_protocols() {
   FREE(myrdate);
   FREE(myrsync);
   FREE(mytns);
+  FREE(mypgsql);
 
 }
 
@@ -296,3 +298,13 @@ void *create_tns() {
   return mytns;
 }
 
+
+void *create_pgsql() {
+  if(mypgsql == NULL) {
+    NEW(mypgsql);
+    mypgsql->name= "PGSQL";
+    mypgsql->check= check_pgsql;
+  }
+  return mypgsql;
+}
+
