@@ -47,6 +47,7 @@
 #define P_DNS            18
 #define P_POSTFIXPOLICY  19
 #define P_TNS            20
+#define P_PGSQL          21
 
 void  gc_protocols();
 
@@ -71,6 +72,7 @@ void* create_ssh();
 void* create_rdate();
 void* create_rsync();
 void* create_tns();
+void* create_pgsql();
 
 /* "Package" locale Protocol routines */
 int check_apache_status(Socket_T);
@@ -93,6 +95,7 @@ int check_ssh(Socket_T);
 int check_rdate(Socket_T);
 int check_rsync(Socket_T);
 int check_tns(Socket_T);
+int check_pgsql(Socket_T);
 
 
 #endif
