@@ -49,7 +49,7 @@
  *
  *  @author Francois Isabelle <Francois.Isabelle@ca.kontron.com>
  *
- *  @version \$Id: rdate.c,v 1.8 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: rdate.c,v 1.9 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -66,7 +66,7 @@ int check_rdate(Socket_T s) {
   ASSERT(s);
   
   if(socket_read(s,(char*) &rdatet, sizeof(time_t)) <= 0) {
-    log("RDATE: error receiving data -- %s\n", STRERROR);
+    LogError("RDATE: error receiving data -- %s\n", STRERROR);
     return FALSE;
   }
   
@@ -74,7 +74,7 @@ int check_rdate(Socket_T s) {
   rdatet = ntohl(rdatet) - TIME_OFFSET;
   
   if((systemt = time(NULL)) == -1) {
-    log("RDATE error: cannot get system time -- %s\n", STRERROR);
+    LogError("RDATE error: cannot get system time -- %s\n", STRERROR);
     return FALSE;
   }
    
@@ -84,7 +84,7 @@ int check_rdate(Socket_T s) {
     delta= (systemt-rdatet);
  
   if(delta > TIME_TOLERANCE) {
-    log("RDATE error: time does not match system time -- %s\n", STRERROR);
+    LogError("RDATE error: time does not match system time -- %s\n", STRERROR);
     return FALSE;
   }
   
