@@ -40,7 +40,7 @@
  * 
  *  @author Igor Homyakov <homyakov@altlinux.ru>
  *
- *  @version \$Id: rsync.c,v 1.13 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: rsync.c,v 1.14 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -54,7 +54,7 @@ int check_rsync(Socket_T s) {
   ASSERT(s);
     
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("RSYNC: did not see server greeting  -- %s\n", STRERROR);
+    LogError("RSYNC: did not see server greeting  -- %s\n", STRERROR);
     return FALSE;
   }
 
@@ -62,32 +62,32 @@ int check_rsync(Socket_T s) {
   
   rc = sscanf(buf, "%s %d", msg, &version);
   if ((rc == EOF) || (rc == 0)) {
-     log("RSYNC: server greeting parse error %s\n", buf);
+     LogError("RSYNC: server greeting parse error %s\n", buf);
     return FALSE;
   }
    
   if(strncasecmp(msg, rsyncd, strlen(rsyncd)) != 0) {
-    log("RSYNC: server sent \"%s\" rather than greeting\n", buf);
+    LogError("RSYNC: server sent \"%s\" rather than greeting\n", buf);
     return FALSE;
   }
 
   if(snprintf(buf, sizeof(buf), "%s %d\n", rsyncd, version) < 0) {
-    log("RSYNC: string copy error -- %s\n", STRERROR);
+    LogError("RSYNC: string copy error -- %s\n", STRERROR);
     return FALSE;
   } 
 	
   if(socket_write(s, buf, strlen(buf)) <= 0) {
-    log("RSYNC: error sending identification string -- %s\n", STRERROR);
+    LogError("RSYNC: error sending identification string -- %s\n", STRERROR);
      return FALSE;
   }
 
   if(socket_print(s, "#list\n") < 0) {
-    log("RSYNC: error sending writing #list command  -- %s\n", STRERROR);
+    LogError("RSYNC: error sending writing #list command  -- %s\n", STRERROR);
     return FALSE;
   }
 
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("RSYNC: did not see server answer  -- %s\n", STRERROR);
+    LogError("RSYNC: did not see server answer  -- %s\n", STRERROR);
     return FALSE;
   }
   
