@@ -37,7 +37,7 @@
  * 
  *  @author Igor Homyakov, <homyakov@altlinux.ru>
  *
- *  @version \$Id: ssh.c,v 1.12 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: ssh.c,v 1.13 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -48,18 +48,18 @@ int check_ssh(Socket_T s) {
   ASSERT(s);
     
   if(!socket_readln(s, buf, sizeof(buf))) {
-    log("SSH: error receiving identification string -- %s\n", STRERROR);
+    LogError("SSH: error receiving identification string -- %s\n", STRERROR);
     return FALSE;
   }
   
   if(! Util_startsWith(buf, "SSH-")) {
-    log("SSH: protocol error %s", buf);
+    LogError("SSH: protocol error %s", buf);
     return FALSE;
   }
 
   /* send identification string back to server */
   if(socket_write(s, buf, strlen(buf)) <= 0) {
-    log("SSH: error sending identification string -- %s\n", STRERROR);
+    LogError("SSH: error sending identification string -- %s\n", STRERROR);
     return FALSE;
   }
    
