@@ -66,7 +66,7 @@
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: sendmail.c,v 1.42 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: sendmail.c,v 1.43 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -163,7 +163,7 @@ void do_send(SendMail_T *S, const char *s, ...) {
   va_end(ap);
   if (socket_write(S->socket, msg, strlen(msg)) <= 0) {
     FREE(msg);
-    log("Sendmail: error sending data to the server '%s' -- %s\n",
+    LogError("Sendmail: error sending data to the server '%s' -- %s\n",
 	S->server, STRERROR);
     siglongjmp(S->error, TRUE);
   }
@@ -177,14 +177,14 @@ static void do_status(SendMail_T *S) {
   char buf[STRLEN];
   
   if(!socket_readln(S->socket, buf, sizeof(buf))) {
-    log("Sendmail: error receiving data from the mailserver '%s' -- %s\n",
+    LogError("Sendmail: error receiving data from the mailserver '%s' -- %s\n",
 	S->server, STRERROR);
     siglongjmp(S->error, TRUE);
   }
   Util_chomp(buf);
   sscanf(buf, "%d", &status);
   if(status >= 400) {
-    log("Sendmail error: %s\n", buf);
+    LogError("Sendmail error: %s\n", buf);
     siglongjmp(S->error, TRUE);
   }
 }
@@ -201,15 +201,15 @@ static void open_server(SendMail_T *S) {
 			  Run.mailserver_timeout);
     if(S->socket)
       break;
-    log("Cannot open a connection to the mailserver '%s:%i' -- %s\n",
+    LogError("Cannot open a connection to the mailserver '%s:%i' -- %s\n",
 	S->server, S->port, STRERROR);
     if(mta && (mta= mta->next)) {
       S->server= mta->host;
       S->port=   mta->port;
-      log("Trying the next mail server '%s:%i'\n", S->server, S->port);
+      LogInfo("Trying the next mail server '%s:%i'\n", S->server, S->port);
       continue;
     } else {
-      log("No mail servers are available\n");
+      LogError("No mail servers are available\n");
       siglongjmp(S->error, TRUE);
     }
   } while(TRUE);
