@@ -1,5 +1,5 @@
 /*
- * Copyright (C), 2000-2005 by the monit project group.
+ * Copyright (C), 2000-2006 by the monit project group.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@
  * communication between two machines. 
  * 
  * @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- * @version \$Id: socket.h,v 1.18 2005/04/03 11:56:51 martinp Exp $
+ * @version \$Id: socket.h,v 1.22 2006/01/01 22:44:02 martinp Exp $
  * @file
  */
 
@@ -174,6 +174,15 @@ int socket_print(Socket_T S, const char *m, ...);
 int socket_write(Socket_T S, void *b, int size);
 
 
+/**
+ * Read a single byte. The byte is returned as an int in the range 0
+ * to 255.
+ * @param S A Socket_T object
+ * @return The byte read, or -1 if the end of the stream has been reached
+ */
+int socket_read_byte(Socket_T S);
+
+
 /**
  * Reads size bytes and stores them into the byte buffer pointed to by b.
  * @param S A Socket_T object
@@ -198,4 +207,11 @@ int socket_read(Socket_T S, void *b, int size);
 char *socket_readln(Socket_T S, char *s, int size);
 
 
+/**
+ * Clears any data that exists in the input buffer
+ * @param S A Socket_T object
+ */
+void socket_reset(Socket_T S);
+
+
 #endif
