@@ -150,7 +150,7 @@ static void handle_ssl_error(char *);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *
- *  @version \$Id: ssl.c,v 1.45 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: ssl.c,v 1.46 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -199,14 +199,14 @@ int embed_ssl_socket (ssl_connection *ssl, int socket) {
 
   } else {
 
-    log("%s: embed_ssl_socket (): Socket error!\n", prog);
+    LogError("%s: embed_ssl_socket (): Socket error!\n", prog);
     goto sslerror;
   }
 
   if ((ssl->handler= SSL_new (ssl->ctx)) == NULL ) {
 
     handle_ssl_error("embed_ssl_socket()");
-    log("%s: embed_ssl_socket (): Cannot initialize the SSL handler!\n", 
+    LogError("%s: embed_ssl_socket (): Cannot initialize the SSL handler!\n", 
 	  prog);
     goto sslerror;
 
@@ -217,7 +217,7 @@ int embed_ssl_socket (ssl_connection *ssl, int socket) {
   if((ssl->socket_bio= BIO_new_socket(ssl->socket, BIO_NOCLOSE)) == NULL) {
 
     handle_ssl_error("embed_ssl_socket()");
-    log("%s: embed_ssl_socket (): Cannot generate IO buffer!\n", prog);
+    LogError("%s: embed_ssl_socket (): Cannot generate IO buffer!\n", prog);
     goto sslerror;
 
   }
@@ -230,7 +230,7 @@ int embed_ssl_socket (ssl_connection *ssl, int socket) {
 
     if((time(NULL)-ssl_time) > SSL_TIMEOUT) {
 
-      log("%s: embed_ssl_socket (): SSL service timeout!\n",
+      LogError("%s: embed_ssl_socket (): SSL service timeout!\n",
 	    prog);
       goto sslerror;
     
@@ -255,7 +255,7 @@ int embed_ssl_socket (ssl_connection *ssl, int socket) {
 
   if (! update_ssl_cert_data(ssl)) {
 
-    log("%s: embed_ssl_socket (): Cannot get the SSL server certificate!\n", 
+    LogError("%s: embed_ssl_socket (): Cannot get the SSL server certificate!\n", 
 	  prog);
     goto sslerror;
 
@@ -378,7 +378,7 @@ ssl_connection *create_ssl_socket(char *hostname, int port, int protocol, int ss
 
   if((socket= create_socket(hostname, port, protocol, NET_TIMEOUT)) == -1) {
 
-    log("%s: create_ssl_socket(): Cannot connect!\n", prog);
+    LogError("%s: create_ssl_socket(): Cannot connect!\n", prog);
     goto sslerror;
 
   }
@@ -595,7 +595,8 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
   if ((ssl_server->method= SSLv23_server_method()) == NULL ) {
 
     handle_ssl_error("init_ssl_server()");
-    log("%s: init_ssl_server (): Cannot initialize the SSL method!\n", prog);
+    LogError("%s: init_ssl_server (): Cannot initialize the SSL method!\n",
+      prog);
     goto sslerror;
 
   }
@@ -603,7 +604,7 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
   if ((ssl_server->ctx= SSL_CTX_new(ssl_server->method)) == NULL ) {
 
     handle_ssl_error("init_ssl_server()");
-    log("%s: init_ssl_server (): Cannot initialize SSL server"
+    LogError("%s: init_ssl_server (): Cannot initialize SSL server"
 	  " certificate handler!\n"
 	  , prog);
     goto sslerror;
@@ -614,8 +615,8 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
 				   SSL_FILETYPE_PEM) <= 0) {
 
     handle_ssl_error("init_ssl_server()");
-    log("%s: init_ssl_server(): Cannot initialize SSL server"
-	  " certificate!\n", prog);
+    LogError("%s: init_ssl_server(): Cannot initialize SSL server"
+      " certificate!\n", prog);
     goto sslerror;
 
   }
@@ -624,7 +625,7 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
 				  SSL_FILETYPE_PEM) <= 0) {
 
     handle_ssl_error("init_ssl_server()");
-    log("%s: init_ssl_server(): Cannot initialize SSL server" 
+    LogError("%s: init_ssl_server(): Cannot initialize SSL server" 
 	  " private key!\n", prog);
     goto sslerror;
 
@@ -633,7 +634,7 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
   if (!SSL_CTX_check_private_key(ssl_server->ctx)) {
 
     handle_ssl_error("init_ssl_server()");
-    log("%s: init_ssl_server(): The private key does not match the"
+    LogError("%s: init_ssl_server(): The private key does not match the"
 	  " certificate public key!\n", prog);
     goto sslerror;
 
@@ -645,7 +646,7 @@ ssl_server_connection *init_ssl_server (char *pemfile, char *clientpemfile) {
   if (!verify_init(ssl_server)) {
 
     handle_ssl_error("init_ssl_server()");
-    log("%s: init_ssl_server(): Verification engine was not"
+    LogError("%s: init_ssl_server(): Verification engine was not"
 	  " properly initialized!\n", prog);
     goto sslerror;
 
@@ -704,7 +705,7 @@ ssl_server_connection *create_ssl_server_socket(char *pemfile, int port,
 
   if ((socket= create_server_socket(port, backlog, bindAddr)) == -1) {
 
-    log("%s: create_ssl_server_socket(): Cannot connect!\n", prog);
+    LogError("%s: create_ssl_server_socket(): Cannot connect!\n", prog);
     goto sslerror;
 
   }
@@ -1039,7 +1040,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
   if((ssl->handler= SSL_new(ssl->ctx)) == NULL) { 
  
     handle_ssl_error("embed_accepted_ssl_socket()");
-    log("%s: embed_accepted_ssl_socket(): Cannot initialize the"
+    LogError("%s: embed_accepted_ssl_socket(): Cannot initialize the"
 	  " SSL handler!\n", prog); 
     goto sslerror;
 
@@ -1047,7 +1048,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
 
   if(socket < 0) {
 
-    log("Socket error!\n");
+    LogError("Socket error!\n");
     goto sslerror;
 
   }
@@ -1057,7 +1058,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
   if((ssl->socket_bio= BIO_new_socket(ssl->socket, BIO_NOCLOSE)) == NULL) {
 
     handle_ssl_error("embed_accepted_ssl_socket()");
-    log("%s: embed_accepted_ssl_socket(): Cannot generate IO buffer!\n", 
+    LogError("%s: embed_accepted_ssl_socket(): Cannot generate IO buffer!\n", 
 	  prog);
     goto sslerror;
 
@@ -1071,7 +1072,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
 
     if((time(NULL)-ssl_time) > SSL_TIMEOUT) {
 
-      log("%s: embed_accepted_ssl_socket(): SSL service timeout!\n", 
+      LogError("%s: embed_accepted_ssl_socket(): SSL service timeout!\n", 
 	    prog);
       goto sslerror;
       
@@ -1096,7 +1097,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
 
   if(!update_ssl_cert_data(ssl) && (ssl->clientpemfile != NULL)) {
 
-    log("%s: The client did not supply a required client certificate!\n", 
+    LogError("%s: The client did not supply a required client certificate!\n", 
 	  prog);
     goto sslerror;
 
@@ -1104,7 +1105,7 @@ int embed_accepted_ssl_socket(ssl_connection *ssl, int socket) {
 
   if (SSL_get_verify_result(ssl->handler)>0) {
 
-    log("%s: Verification of the certificate has failed!\n", 
+    LogError("%s: Verification of the certificate has failed!\n", 
 	  prog);
     goto sslerror;
 
@@ -1385,7 +1386,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
 
   default:
 
-    log("%s: new_ssl_connection(): Unknown SSL version!\n", prog);
+    LogError("%s: new_ssl_connection(): Unknown SSL version!\n", prog);
     goto sslerror;
 
   }
@@ -1393,7 +1394,8 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
   if (ssl->method == NULL ) {
 
     handle_ssl_error("new_ssl_connection()");
-    log("%s: new_ssl_connection(): Cannot initialize SSL method!\n", prog);
+    LogError("%s: new_ssl_connection(): Cannot initialize SSL method!\n",
+      prog);
     goto sslerror;
 
   } 
@@ -1401,8 +1403,8 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
   if ((ssl->ctx= SSL_CTX_new (ssl->method)) == NULL ) {
 
     handle_ssl_error("new_ssl_connection()");
-    log("%s: new_ssl_connection(): Cannot initialize SSL server certificate"
-	  " handler!\n", prog);
+    LogError("%s: new_ssl_connection(): Cannot initialize SSL server "
+      "certificate handler!\n", prog);
     goto sslerror;
 
   }
@@ -1413,7 +1415,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
 				     SSL_FILETYPE_PEM) <= 0) {
 
       handle_ssl_error("new_ssl_connection()");
-      log("%s: new_ssl_connection(): Cannot initialize SSL server"
+      LogError("%s: new_ssl_connection(): Cannot initialize SSL server"
 	    " certificate!\n", prog);
       goto sslerror;
       
@@ -1423,7 +1425,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
 				    SSL_FILETYPE_PEM) <= 0) {
 
       handle_ssl_error("new_ssl_connection()");
-      log("%s: new_ssl_connection(): Cannot initialize SSL server"
+      LogError("%s: new_ssl_connection(): Cannot initialize SSL server"
 	    " private key!\n", prog);
       goto sslerror;
 
@@ -1432,7 +1434,7 @@ ssl_connection *new_ssl_connection(char *clientpemfile, int sslversion) {
     if (!SSL_CTX_check_private_key(ssl->ctx)) {
 
       handle_ssl_error("new_ssl_connection()");
-      log("%s: new_ssl_connection(): Private key does not match the"
+      LogError("%s: new_ssl_connection(): Private key does not match the"
 	    " certificate public key!\n", 
 	    prog);
       goto sslerror;
@@ -1546,7 +1548,7 @@ static int verify_init(ssl_server_connection *ssl_server) {
 
   if ( -1 == stat(ssl_server->clientpemfile, &stat_buf )) {
 
-    log("%s: verify_init(): Cannot stat the SSL pem path '%s' -- %s\n",
+    LogError("%s: verify_init(): Cannot stat the SSL pem path '%s' -- %s\n",
 	  prog, Run.httpsslclientpem, STRERROR);
 
     goto end_error;
@@ -1559,14 +1561,14 @@ static int verify_init(ssl_server_connection *ssl_server) {
 				       ssl_server->clientpemfile)) {
 
       handle_ssl_error("verify_init()");
-      log("%s: verify_init(): Error setting verify directory to %s\n", 
+      LogError("%s: verify_init(): Error setting verify directory to %s\n", 
 	    Run.httpsslclientpem);
 
       goto end_error;
 
     }
 
-    log("%s: verify_init(): Loaded SSL client pem directory '%s'\n", 
+    LogInfo("%s: verify_init(): Loaded SSL client pem directory '%s'\n", 
 	prog, ssl_server->clientpemfile);
 
     /* Monits server cert for cli support ! */
@@ -1575,14 +1577,14 @@ static int verify_init(ssl_server_connection *ssl_server) {
 				      NULL)) {
 
       handle_ssl_error("verify_init()");
-      log("%s: verify_init(): Error loading verify certificates from %s\n",
+      LogError("%s: verify_init(): Error loading verify certificates from %s\n",
 	    prog, ssl_server->pemfile);
 
       goto end_error;
 
     }
 
-    log("%s: verify_init(): Loaded monit's SSL pem server file '%s'\n", 
+    LogInfo("%s: verify_init(): Loaded monit's SSL pem server file '%s'\n", 
 	prog, ssl_server->pemfile);
 
   } else if (S_ISREG(stat_buf.st_mode)) {
@@ -1592,14 +1594,14 @@ static int verify_init(ssl_server_connection *ssl_server) {
 				      NULL)) {
 
       handle_ssl_error("verify_init()");
-      log("%s: verify_init(): Error loading verify certificates from %s\n",
+      LogError("%s: verify_init(): Error loading verify certificates from %s\n",
 	    prog, Run.httpsslclientpem);
 
       goto end_error;
 
     }
 
-    log("%s: verify_init(): Loaded SSL pem client file '%s'\n", 
+    LogInfo("%s: verify_init(): Loaded SSL pem client file '%s'\n", 
 	prog, ssl_server->clientpemfile);
 
     /* Monits server cert for cli support ! */
@@ -1608,14 +1610,14 @@ static int verify_init(ssl_server_connection *ssl_server) {
 				      NULL)) {
 
       handle_ssl_error("verify_init()");
-      log("%s: verify_init(): Error loading verify certificates from %s\n",
+      LogError("%s: verify_init(): Error loading verify certificates from %s\n",
 	    prog, ssl_server->pemfile);
 
       goto end_error;
 
     }
 
-    log("%s: verify_init(): Loaded monit's SSL pem server file '%s'\n", 
+    LogInfo("%s: verify_init(): Loaded monit's SSL pem server file '%s'\n", 
 	prog, ssl_server->pemfile);
 
     SSL_CTX_set_client_CA_list(ssl_server->ctx,
@@ -1623,7 +1625,7 @@ static int verify_init(ssl_server_connection *ssl_server) {
 
   } else {
 
-    log("%s: verify_init(): SSL client pem path is no file or directory %s\n",
+    LogError("%s: verify_init(): SSL client pem path is no file or directory %s\n",
 	  prog, ssl_server->clientpemfile);
 
     goto end_error;
@@ -1671,7 +1673,7 @@ static int verify_callback(int preverify_ok, X509_STORE_CTX *ctx) {
 			       &found_cert)!=1) {
 
     handle_ssl_error("verify_callback()");
-    log("%s: verify_callback(): SSL connection rejected. No matching "
+    LogError("%s: verify_callback(): SSL connection rejected. No matching "
 	  "certificate found.", prog);
 
     goto reject; 
@@ -1726,7 +1728,7 @@ static int check_preverify(X509_STORE_CTX *ctx) {
 
     /* Remote site specified a certificate, but it's not correct */
     
-    log("%s: check_preverify(): SSL connection rejected because"
+    LogError("%s: check_preverify(): SSL connection rejected because"
 	  " certificate verification has failed -- Error %i\n", 
 	  prog, ctx->error);
     return FALSE; /* Reject connection */
@@ -1739,7 +1741,7 @@ static int check_preverify(X509_STORE_CTX *ctx) {
     
     /* Let's accept self signed certs for the moment! */
     
-    log("%s: check_preverify(): SSL connection accepted with"
+    LogInfo("%s: check_preverify(): SSL connection accepted with"
 	" self signed certificate!\n", prog);
 
     ctx->error=0;
@@ -1752,7 +1754,7 @@ static int check_preverify(X509_STORE_CTX *ctx) {
     
     /* Let's accept any purpose certs for the moment! */
     
-    log("%s: check_preverify(): SSL connection accepted "
+    LogInfo("%s: check_preverify(): SSL connection accepted "
 	"with invalid purpose!\n", prog);
 
     ctx->error=0;
@@ -1760,7 +1762,7 @@ static int check_preverify(X509_STORE_CTX *ctx) {
 
   } 
     
-  log("%s: check_preverify(): SSL connection rejected because "
+  LogError("%s: check_preverify(): SSL connection rejected because "
 	"certificate verification has failed -- Error %i!\n", 
 	prog, ctx->error);
   return FALSE; /* Reject connection */
@@ -1776,7 +1778,7 @@ static void verify_info(ssl_server_connection *ssl_server) {
   STACK_OF(X509_NAME) *stack;
   
   stack=SSL_CTX_get_client_CA_list(ssl_server->ctx);
-  log("%s: verify_info(): Found %d client certificates\n", prog, 
+  LogInfo("%s: verify_info(): Found %d client certificates\n", prog, 
       sk_X509_NAME_num(stack));
   
 }
@@ -1900,18 +1902,18 @@ static int handle_connection_error(int code, ssl_connection *ssl,
       if (can_read(ssl->socket, timeout))
           return TRUE;
       else
-          log("%s: %s: Openssl read timeout error!\n", prog, operation);
+          LogError("%s: %s: Openssl read timeout error!\n", prog, operation);
           return FALSE;
       
   case SSL_ERROR_WANT_WRITE:
       if (can_read(ssl->socket, timeout))
           return TRUE;
       else
-          log("%s: %s: Openssl write timeout error!\n", prog, operation);
+          LogError("%s: %s: Openssl write timeout error!\n", prog, operation);
           return FALSE;
     
   case SSL_ERROR_SYSCALL:
-    log("%s: %s: Openssl syscall error: %s!\n", prog, operation, 
+    LogError("%s: %s: Openssl syscall error: %s!\n", prog, operation, 
 	  STRERROR);
     return FALSE;
 
@@ -1920,7 +1922,7 @@ static int handle_connection_error(int code, ssl_connection *ssl,
     return FALSE;
       
   default:
-    log("%s: %s: Openssl error!\n", prog, operation);
+    LogError("%s: %s: Openssl error!\n", prog, operation);
 
   }
 
@@ -1933,7 +1935,7 @@ static int handle_connection_error(int code, ssl_connection *ssl,
  */
 static void handle_ssl_error(char *operation) {
 
-  log("%s: %s: Openssl engine error: %s\n", prog, operation, SSLERROR);
+  LogError("%s: %s: Openssl engine error: %s\n", prog, operation, SSLERROR);
 
 }
 
