@@ -64,7 +64,7 @@
  *  file, if not set, the default is ~/.monit.state.
  *
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
- *  @version \$Id: state.c,v 1.25 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: state.c,v 1.28 2006/05/10 16:32:22 martinp Exp $
  *  @file
  */
 
@@ -117,7 +117,7 @@ void State_save() {
   l= Util_getNumberOfServices();
   
   if(fwrite(&l, 1, sizeof (int), S) != sizeof(int)) {
-    log("%s: Unable to save monit state information to '%s'\n",
+    LogError("%s: Unable to save monit state information to '%s'\n",
 	prog, Run.statefile);
     goto error;
   }
@@ -125,7 +125,7 @@ void State_save() {
   for(s= servicelist; s; s= s->next) {
     clone_state(s, &state);
     if(fwrite(&state, 1, sizeof(State_T), S) != sizeof(State_T)) {
-      log("%s: An error occured when saving monit state information "
+      LogError("%s: An error occured when saving monit state information "
 	  "for the service %s\n", prog, s->name);
       goto error;
     }
@@ -196,7 +196,7 @@ void State_update() {
 
   errno= 0;
   if(fread(&l, 1, sizeof (int), S) != sizeof(int)) {
-    log("%s: Unable to read monit state information from '%s'\n",
+    LogError("%s: Unable to read monit state information from '%s'\n",
 	prog, Run.statefile);
     has_error= TRUE;
     goto error;
@@ -205,7 +205,7 @@ void State_update() {
   if(l > 0) {
     for(i=0; i<l; i++) {
       if(fread(&s, 1, sizeof(State_T), S) != sizeof(State_T)) {
-	log("%s: An error occured when updating monit state information\n",
+	LogError("%s: An error occured when updating monit state information\n",
 	    prog);
 	has_error= TRUE;
 	goto error;
@@ -238,7 +238,7 @@ static FILE *open_state(const char *mode) {
   umask(MYPIDMASK);
   
   if((S= fopen(Run.statefile, mode)) == NULL) {
-    log("%s: Cannot open the monit state file '%s' -- %s\n",
+    LogError("%s: Cannot open the monit state file '%s' -- %s\n",
 	prog, Run.statefile, STRERROR);
     
     return NULL;
@@ -252,7 +252,11 @@ static FILE *open_state(const char *mode) {
 
 static void close_state(FILE *S) {
 
-  ASSERT(fclose(S)==0);
+  if(fclose(S) != 0) {
+    LogCritical("%s: Cannot close the monit state file '%s' -- %s\n",
+	prog, Run.statefile, STRERROR);
+    
+  }
 
 }
 
