@@ -60,7 +60,7 @@
  *  @author Jan-Henrik Haukeland, <hauk@tildeslash.com>
  *  @author Christian Hopp, <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: status.c,v 1.60 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: status.c,v 1.61 2006/04/27 20:16:03 martinp Exp $
  *
  *  @file
  */
@@ -82,13 +82,14 @@ int status(char *level) {
   char *auth= NULL;
 
   if(!exist_daemon()) {
-    log("%s: no status available -- the monit daemon is not running\n", prog);
+    LogError("%s: no status available -- the monit daemon is not running\n",
+      prog);
     return status;
   }
 
   if(!(sock= socket_new(Run.bind_addr?Run.bind_addr:"localhost", Run.httpdport,
                         SOCKET_TCP, Run.httpdssl, NET_TIMEOUT))) {
-    log("%s: error connecting to the monit daemon\n", prog);
+    LogError("%s: error connecting to the monit daemon\n", prog);
     return status;
   }
 
@@ -107,7 +108,7 @@ int status(char *level) {
   }
 
   if(!status) {
-    log("%s: cannot read status from the monit daemon\n", prog);
+    LogError("%s: cannot read status from the monit daemon\n", prog);
   } else {
     while(socket_readln(sock, buf, LINE)) {
       printf("%s", buf);
