@@ -119,7 +119,7 @@ static int is_url_unsafe(unsigned char *);
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.c,v 1.180 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: util.c,v 1.184 2006/04/27 20:16:03 martinp Exp $
  *  @file
  */
 
@@ -419,8 +419,17 @@ void Util_handleEscapes(char *buf) {
           
         case '0':
           if(*(buf+editpos+2)=='x') {
-            *(buf+insertpos)=x2c(&buf[editpos+3]);
-            editpos+=4;
+            if((*(buf+editpos+3)=='0' && *(buf+editpos+4)=='0')) {
+              /* Don't swap \0x00 with 0 to avoid truncating the string. 
+              Currently the only place where we support sending of 0 bytes
+              is in check_generic(). The \0x00 -> 0 byte swap is performed
+              there and in-place.
+              */
+              *(buf+insertpos)=*(buf+editpos);
+            } else {
+              *(buf+insertpos)=x2c(&buf[editpos+3]);
+              editpos+=4;
+            } 
           }
           break;
           
@@ -446,6 +455,51 @@ void Util_handleEscapes(char *buf) {
 }
 
 
+/**
+ * Variant of Util_handleEscapes() which only handle \0x00 escape sequences 
+ * in a string
+ * @param buf A string
+ * @return The new length of buf
+ */
+int Util_handle0Escapes(char *buf) {
+  
+  int editpos;
+  int insertpos;
+  
+  ASSERT(buf);
+  
+  for(editpos=insertpos=0; *(buf+editpos)!='\0'; editpos++, insertpos++) {
+    
+    if(*(buf+editpos) == '\\' ) {
+      
+      switch(*(buf+editpos+1)) {
+        
+        case '0':
+          if(*(buf+editpos+2)=='x') {
+            *(buf+insertpos)=x2c(&buf[editpos+3]);
+            editpos+=4;
+          }
+          break;
+
+        default:
+          *(buf+insertpos)=*(buf+editpos);
+          
+      }  
+      
+    } else {
+      
+      *(buf+insertpos)=*(buf+editpos);
+      
+    }  
+    
+  }
+  *(buf+insertpos)='\0';
+  
+  return insertpos;
+  
+}
+
+
 /**
  * @param name A service name as stated in the config file
  * @return the named service or NULL if not found
@@ -1114,18 +1168,18 @@ pid_t Util_getPid(char *pidfile) {
     return FALSE;
   }
   if(! File_isFile(pidfile)) {
-    log("%s: pidfile '%s' is not a regular file\n",prog, pidfile);
+    LogError("%s: pidfile '%s' is not a regular file\n",prog, pidfile);
     return FALSE;
   }
   if((file= fopen(pidfile,"r")) == (FILE *)NULL) {
-    log("%s: Error opening the pidfile '%s' -- %s\n",
+    LogError("%s: Error opening the pidfile '%s' -- %s\n",
 	prog, pidfile, STRERROR);
     return FALSE ;
   }
   fscanf(file, "%d", &pid);
   fclose(file);
   if(pid == -1) {
-    log("%s: pidfile `%s' does not contain a valid pidnumber\n",
+    LogError("%s: pidfile `%s' does not contain a valid pidnumber\n",
 	prog, pidfile);
     return (FALSE);
   }
@@ -1379,7 +1433,7 @@ char *Util_getBasicAuthHeader() {
              c->uname,
              c->passwd);
     if(! (b64= encode_base64(strlen(buf), (unsigned char *)buf)) ) {
-      log("Failed to base64 encode authentication header\n");
+      LogError("Failed to base64 encode authentication header\n");
       FREE(b64);
       return NULL;
     }
@@ -1389,7 +1443,7 @@ char *Util_getBasicAuthHeader() {
     return auth;
   }
 
-  log("Cleattext credentials needed for basic authorization!\n");
+  LogError("Cleattext credentials needed for basic authorization!\n");
   return NULL;
 
 }
@@ -1471,7 +1525,8 @@ void Util_redirectStdFds() {
   int i;
   for(i= 0; i < 3; i++) {
     if(close(i) == -1 || open("/dev/null", O_RDWR) != i) {
-      log("Cannot reopen standard file descriptor (%d) -- %s\n", i, STRERROR);
+      LogError("Cannot reopen standard file descriptor (%d) -- %s\n",
+        i, STRERROR);
     }
   }
 }
@@ -1550,7 +1605,7 @@ int Util_checkCredentials(char *uname, char *outside) {
       ASSERT(temp);
       *temp= '\0';
       if (md5_crypt(outside, id, salt, outside_crypt, STRLEN) == NULL) {
-	log("Cannot generate MD5 digest error.\n");
+	LogError("Cannot generate MD5 digest error.\n");
 	return FALSE;
       }
       break;
@@ -1565,7 +1620,7 @@ int Util_checkCredentials(char *uname, char *outside) {
       break;
     }
   default:
-    log("Unknown password digestion method.\n");
+    LogError("Unknown password digestion method.\n");
     return FALSE;
   }
 
@@ -1687,9 +1742,11 @@ char *Util_getHTTPHostHeader(Socket_T s, char *hostBuf, int len) {
      inet_aton(socket_get_remote_host(s), NULL)) {
     *hostBuf= 0;
   } else {
-    snprintf(hostBuf, len, "%s:%d", 
-	     socket_get_remote_host(s),
-	     socket_get_remote_port(s));
+    if(socket_get_remote_port(s)==80)
+       snprintf(hostBuf, len, "%s", socket_get_remote_host(s));
+     else
+       snprintf(hostBuf, len, "%s:%d", socket_get_remote_host(s),
+                socket_get_remote_port(s));
   }
   return hostBuf;
 }
@@ -1722,7 +1779,7 @@ int Util_evalQExpression(int operator, int left, int right) {
 	  return TRUE;
       break;
   default:
-      log("Unknown comparison operator\n");
+      LogError("Unknown comparison operator\n");
       return FALSE;
   }
 
