@@ -30,7 +30,7 @@
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *  @author Michael Amster, <mamster@webeasy.com> 
  *
- *  @version \$Id: util.h,v 1.14 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: util.h,v 1.15 2006/04/11 23:23:26 hauk Exp $
  *  @file
  */
 
@@ -136,6 +136,15 @@ int Util_startsWith(const char *a, const char *b);
 void Util_handleEscapes(char *buf);
 
 
+/**
+ * Variant of Util_handleEscapes() which only handle \0x00 escape sequences 
+ * in a string
+ * @param buf A string
+ * @return The new length of buf
+ */
+int Util_handle0Escapes(char *buf);
+
+
 /**
  * @param name A service name as stated in the config file
  * @return the named service or NULL if not found
