@@ -90,7 +90,7 @@
  *  @author Martin Pala <martinp@tildeslash.com>
  *  @author Christian Hopp <chopp@iei.tu-clausthal.de>
  *
- *  @version \$Id: validate.c,v 1.151 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: validate.c,v 1.152 2006/04/27 20:16:03 martinp Exp $
  *  @file
  */
 
@@ -200,7 +200,7 @@ int check_process(Service_T s) {
         check_process_resources(s, pr);
       }
     } else {
-      log("'%s' failed to get service data\n", s->name);
+      LogError("'%s' failed to get service data\n", s->name);
     }
 
   }
@@ -481,7 +481,8 @@ int check_remote_host(Service_T s) {
         break;
 
       default:
-        log("'%s' error -- unknown ICMP type: [%d]\n", s->name, icmp->type);
+        LogError("'%s' error -- unknown ICMP type: [%d]\n",
+          s->name, icmp->type);
         return FALSE;
 
       }
@@ -870,7 +871,8 @@ static void check_process_resources(Service_T s, Resource_T r) {
     break;
 
   default:
-    log("'%s' error -- unknown resource ID: [%d]\n", s->name, r->resource_id);
+    LogError("'%s' error -- unknown resource ID: [%d]\n",
+      s->name, r->resource_id);
     return;
   }
 
@@ -912,7 +914,7 @@ static void check_checksum(Service_T s) {
         changed= strncmp(cs->hash, s->inf->cs_sum, 40);
         break;
       default:
-        log("'%s' unknown hash type\n", s->name);
+        LogError("'%s' unknown hash type\n", s->name);
         FREE(s->inf->cs_sum);
         return;
     }
@@ -1324,7 +1326,7 @@ static void check_device_resources(Service_T s, Device_T td) {
   ASSERT(s && td);
 
   if( (td->limit_percent < 0) && (td->limit_absolute < 0) ) {
-    log("'%s' error: device limit not set\n", s->name);
+    LogError("'%s' error: device limit not set\n", s->name);
     return;
   }
 
@@ -1393,7 +1395,8 @@ static void check_device_resources(Service_T s, Device_T td) {
       return;
       
   default:
-      log("'%s' error -- unknown resource type: [%d]\n", s->name, td->resource);
+      LogError("'%s' error -- unknown resource type: [%d]\n", s->name,
+        td->resource);
       return;
   }
   
