@@ -50,7 +50,7 @@
  *
  *  @author Martin Pala, <martinp@tildeslash.com>
  *
- *  @version \$Id: xml.c,v 1.22 2006/01/01 22:44:02 martinp Exp $
+ *  @version \$Id: xml.c,v 1.23 2006/04/07 11:46:00 martinp Exp $
  *
  *  @file
  */
@@ -144,7 +144,7 @@ static void document_head(Buffer_T *B) {
       "\t\t\t<port>%d</port>\r\n"
       "\t\t\t<ssl>%d</ssl>\r\n"
       "\t\t</httpd>\r\n",
-      Run.bind_addr,
+      Run.bind_addr?Run.bind_addr:"",
       Run.httpdport,
       Run.httpdssl);
   }
@@ -182,7 +182,7 @@ static void status_service(Service_T S, Buffer_T *B, short L) {
 	    "\t\t<group>%s</group>\r\n",
 	    S->type,
 	    S->collected,
-	    S->name,
+	    S->name?S->name:"",
 	    S->error,
 	    S->monitor,
 	    S->group?S->group:"");
@@ -295,11 +295,11 @@ static void status_service(Service_T S, Buffer_T *B, short L) {
   		    "\t\t\t<protocol>%s</protocol>\r\n"
   		    "\t\t\t<responsetime>%.3f</responsetime>\r\n"
   		    "\t\t</port>\r\n",
-  		    p->hostname,
+  		    p->hostname?p->hostname:"",
   		    p->port,
   		    p->request?p->request:"",
   		    Util_portTypeDescription(p),
-  		    p->protocol->name,
+  		    p->protocol->name?p->protocol->name:"",
   		    p->is_available?p->response:-1.);
   	  
           } else if(p->family == AF_UNIX) {
@@ -309,8 +309,8 @@ static void status_service(Service_T S, Buffer_T *B, short L) {
 		    "\t\t\t<protocol>%s</protocol>\r\n"
 		    "\t\t\t<responsetime>%.3f</responsetime>\r\n"
 		    "\t\t</unix>\r\n",
-		    p->pathname,
-		    p->protocol->name,
+		    p->pathname?p->pathname:"",
+		    p->protocol->name?p->protocol->name:"",
 		    p->is_available?p->response:-1.);
           }
         }
